@@ -2,7 +2,13 @@ use std::collections::HashMap;
 
 use serde_json::{json, Value};
 
-use crate::{model::interactions::application_command::ApplicationCommandOptionType, utils};
+use crate::internal::prelude::*;
+use crate::model::channel::ChannelType;
+use crate::model::interactions::application_command::{
+    ApplicationCommandOptionType,
+    ApplicationCommandType,
+};
+use crate::utils;
 
 /// A builder for creating a new [`ApplicationCommandOption`].
 ///
@@ -95,6 +101,17 @@ impl CreateApplicationCommandOption {
         self
     }
 
+    /// Optionally enable/disable autocomplete interactions for this option.
+    ///
+    /// **Notes**:
+    /// - May not be set to `true` if `choices` are set
+    /// - Options using `autocomplete` are not confined to only use given choices
+    pub fn set_autocomplete(&mut self, value: bool) -> &mut Self {
+        self.0.insert("autocomplete", Value::Bool(value));
+
+        self
+    }
+
     /// If the option is a [`SubCommandGroup`] or [`SubCommand`], nested options are its parameters.
     ///
     /// **Note**: A command can have up to 25 subcommand groups, or subcommands. A subcommand group can have up to 25 subcommands. A subcommand can have up to 25 options.
@@ -124,6 +141,51 @@ impl CreateApplicationCommandOption {
 
         self
     }
+
+    /// If the option is a [`Channel`], it will only be able to show these types.
+    ///
+    /// [`Channel`]: crate::model::interactions::application_command::ApplicationCommandOptionType::Channel
+    pub fn channel_types(&mut self, channel_types: &[ChannelType]) -> &mut Self {
+        self.0.insert(
+            "channel_types",
+            Value::Array(
+                channel_types
+                    .iter()
+                    .map(|i| Value::Number(Number::from(*i as u8)))
+                    .collect::<Vec<_>>(),
+            ),
+        );
+
+        self
+    }
+
+    /// Sets the minimum permitted value for this integer option
+    pub fn min_int_value(&mut self, value: i32) -> &mut Self {
+        self.0.insert("min_value", serde_json::Value::from(value));
+
+        self
+    }
+
+    /// Sets the maximum permitted value for this integer option
+    pub fn max_int_value(&mut self, value: i32) -> &mut Self {
+        self.0.insert("max_value", serde_json::Value::from(value));
+
+        self
+    }
+
+    /// Sets the minimum permitted value for this number option
+    pub fn min_number_value(&mut self, value: f64) -> &mut Self {
+        self.0.insert("min_value", serde_json::Value::from(value));
+
+        self
+    }
+
+    /// Sets the maximum permitted value for this number option
+    pub fn max_number_value(&mut self, value: f64) -> &mut Self {
+        self.0.insert("max_value", serde_json::Value::from(value));
+
+        self
+    }
 }
 
 /// A builder for creating a new [`ApplicationCommand`].
@@ -143,6 +205,12 @@ impl CreateApplicationCommand {
         self
     }
 
+    /// Specifies the type of the application command.
+    pub fn kind(&mut self, kind: ApplicationCommandType) -> &mut Self {
+        self.0.insert("type", Value::Number(Number::from(kind as u8)));
+        self
+    }
+
     /// Specifies if the command should not be usable by default
     ///
     /// **Note**: Setting it to false will disable it for anyone,
