@@ -104,7 +104,7 @@ impl<'a> CreateInteractionResponseFollowup<'a> {
             .entry("embeds")
             .or_insert_with(|| Value::Array(Vec::new()))
             .as_array_mut()
-            .unwrap()
+            .expect("couldn't add embed")
             .push(embed);
 
         self
@@ -142,8 +142,7 @@ impl<'a> CreateInteractionResponseFollowup<'a> {
         self
     }
 
-    /// Sets the components of this message.
-    #[cfg(feature = "unstable_discord_api")]
+    /// Creates components for this message.
     pub fn components<F>(&mut self, f: F) -> &mut Self
     where
         F: FnOnce(&mut CreateComponents) -> &mut CreateComponents,
@@ -154,4 +153,10 @@ impl<'a> CreateInteractionResponseFollowup<'a> {
         self.0.insert("components", Value::Array(components.0));
         self
     }
+
+    /// Sets the components of this message.
+    pub fn set_components(&mut self, components: CreateComponents) -> &mut Self {
+        self.0.insert("components", Value::Array(components.0));
+        self
+    }
 }
