@@ -467,11 +467,13 @@ impl Cache {
     /// #[serenity::async_trait]
     /// impl EventHandler for Handler {
     ///     async fn message(&self, context: Context, message: Message) {
-    ///
     ///         let channel = match context.cache.guild_channel(message.channel_id).await {
     ///             Some(channel) => channel,
     ///             None => {
-    ///                 let result = message.channel_id.say(&context, "Could not find guild's channel data").await;
+    ///                 let result = message
+    ///                     .channel_id
+    ///                     .say(&context, "Could not find guild's channel data")
+    ///                     .await;
     ///                 if let Err(why) = result {
     ///                     println!("Error sending message: {:?}", why);
     ///                 }
@@ -1038,6 +1040,8 @@ mod test {
                     discriminator: 1,
                     name: "user 1".to_owned(),
                     public_flags: None,
+                    banner: None,
+                    accent_colour: None,
                 },
                 channel_id: ChannelId(2),
                 guild_id: Some(GuildId(1)),
