@@ -76,12 +76,8 @@ pub use crate::CacheAndHttp;
 /// A builder implementing [`Future`] building a [`Client`] to interact with Discord.
 #[cfg(feature = "gateway")]
 pub struct ClientBuilder<'a> {
-    // FIXME: Remove this allow attribute once `application_id` is no longer feature-gated
-    // under `unstable_discord_api`.
-    #[allow(dead_code)]
-    token: Option<String>,
     data: Option<TypeMap>,
-    http: Option<Http>,
+    http: Http,
     fut: Option<BoxFuture<'a, Result<Client>>>,
     intents: GatewayIntents,
     #[cfg(feature = "unstable_discord_api")]
@@ -89,6 +85,7 @@ pub struct ClientBuilder<'a> {
     #[cfg(feature = "cache")]
     timeout: Option<Duration>,
     #[cfg(feature = "cache")]
+    // Option in order to take() it out in the Future impl
     cache_settings: Option<CacheSettings>,
     #[cfg(feature = "framework")]
     framework: Option<Arc<Box<dyn Framework + Send + Sync + 'static>>>,
@@ -100,11 +97,10 @@ pub struct ClientBuilder<'a> {
 
 #[cfg(feature = "gateway")]
 impl<'a> ClientBuilder<'a> {
-    fn _new() -> Self {
+    fn _new(http: Http) -> Self {
         Self {
-            token: None,
             data: Some(TypeMap::new()),
-            http: None,
+            http,
             fut: None,
             intents: GatewayIntents::non_privileged(),
             #[cfg(feature = "unstable_discord_api")]
@@ -130,7 +126,7 @@ impl<'a> ClientBuilder<'a> {
     /// a framework via the [`Self::framework`] or [`Self::framework_arc`] method,
     /// otherwise awaiting the builder will cause a panic.
     pub fn new(token: impl AsRef<str>) -> Self {
-        Self::_new().token(token)
+        Self::_new(Http::new_with_token(token.as_ref()))
     }
 
     /// Construct a new builder with a [`Http`] instance to calls methods on
@@ -143,37 +139,40 @@ impl<'a> ClientBuilder<'a> {
     ///
     /// [`Http`]: crate::http::Http
     pub fn new_with_http(http: Http) -> Self {
-        let mut c = Self::_new();
-        c.http = Some(http);
-        c
+        Self::_new(http)
     }
 
     /// Sets a token for the bot. If the token is not prefixed "Bot ",
     /// this method will automatically do so.
     pub fn token(mut self, token: impl AsRef<str>) -> Self {
-        let token = token.as_ref().trim();
-
-        let token =
-            if token.starts_with("Bot ") { token.to_string() } else { format!("Bot {}", token) };
-
-        self.token = Some(token.clone());
-
-        self.http = Some(Http::new_with_token(&token));
+        self.http = Http::new_with_token(token.as_ref());
 
         self
     }
 
+    /// Gets the current token used for the [`Http`] client.
+    ///
+    /// [`Http`]: crate::http::Http
+    pub fn get_token(&self) -> &str {
+        &self.http.token
+    }
+
     /// Sets the application id.
     #[cfg(feature = "unstable_discord_api")]
     pub fn application_id(mut self, application_id: u64) -> Self {
         self.application_id = Some(ApplicationId(application_id));
 
-        self.http =
-            Some(Http::new_with_token_application_id(&self.token.clone().unwrap(), application_id));
+        self.http = Http::new_with_token_application_id(self.get_token(), application_id);
 
         self
     }
 
+    /// Gets the application ID, if already initialized. See [`Self::application_id`] for more info.
+    #[cfg(feature = "unstable_discord_api")]
+    pub fn get_application_id(&self) -> Option<ApplicationId> {
+        self.application_id
+    }
+
     /// Sets the entire [`TypeMap`] that will be available in [`Context`]s.
     /// A [`TypeMap`] must not be constructed manually: [`Self::type_map_insert`]
     /// can be used to insert one type at a time.
@@ -183,19 +182,17 @@ impl<'a> ClientBuilder<'a> {
         self
     }
 
+    /// Gets the type map, if already initialized. See [`Self::type_map`] for more info.
+    pub fn get_type_map(&self) -> Option<&TypeMap> {
+        self.data.as_ref()
+    }
+
     /// Insert a single `value` into the internal [`TypeMap`] that will
     /// be available in [`Context::data`].
     /// This method can be called multiple times in order to populate the
     /// [`TypeMap`] with `value`s.
     pub fn type_map_insert<T: TypeMapKey>(mut self, value: T::Value) -> Self {
-        if let Some(ref mut data) = self.data {
-            data.insert::<T>(value);
-        } else {
-            let mut type_map = TypeMap::new();
-            type_map.insert::<T>(value);
-
-            self.data = Some(type_map);
-        }
+        self.data.get_or_insert_with(TypeMap::new).insert::<T>(value);
 
         self
     }
@@ -214,6 +211,13 @@ impl<'a> ClientBuilder<'a> {
         self
     }
 
+    /// Gets the cache update timeout, if already initialized. See [`Self::cache_update_timeout`]
+    /// for more info.
+    #[cfg(feature = "cache")]
+    pub fn get_cache_update_timeout(&self) -> Option<Duration> {
+        self.timeout
+    }
+
     /// Sets the settings of the cache.
     /// Refer to [`Settings`] for more information.
     ///
@@ -230,6 +234,15 @@ impl<'a> ClientBuilder<'a> {
         self
     }
 
+    /// Gets the cache settings. See [`Self::cache_settings`] for more info.
+    #[cfg(feature = "cache")]
+    pub fn get_cache_settings(&self) -> &CacheSettings {
+        // unwrap() is ok because cache_settings will only ever be None in the middle of being
+        // .await'ed
+        #[allow(clippy::unwrap_used)]
+        self.cache_settings.as_ref().unwrap()
+    }
+
     /// Sets the command framework to be used. It will receive messages sent
     /// over the gateway and then consider - based on its settings - whether to
     /// dispatch a command.
@@ -261,6 +274,12 @@ impl<'a> ClientBuilder<'a> {
         self
     }
 
+    /// Gets the framework, if already initialized. See [`Self::framework`] for more info.
+    #[cfg(feature = "framework")]
+    pub fn get_framework(&self) -> Option<Arc<Box<dyn Framework + Send + Sync>>> {
+        self.framework.clone()
+    }
+
     /// Sets the voice gateway handler to be used. It will receive voice events sent
     /// over the gateway and then consider - based on its settings - whether to
     /// dispatch a command.
@@ -294,6 +313,12 @@ impl<'a> ClientBuilder<'a> {
         self
     }
 
+    /// Gets the voice manager, if already initialized. See [`Self::voice_manager`] for more info.
+    #[cfg(feature = "voice")]
+    pub fn get_voice_manager(&self) -> Option<Arc<dyn VoiceGatewayManager + Send + Sync>> {
+        self.voice_manager.clone()
+    }
+
     /// Sets all intents directly, replacing already set intents.
     /// Intents are a bitflag, you can combine them by performing the
     /// `|`-operator.
@@ -325,6 +350,11 @@ impl<'a> ClientBuilder<'a> {
         self
     }
 
+    /// Gets the intents. See [`Self::intents`] for more info.
+    pub fn get_intents(&self) -> GatewayIntents {
+        self.intents
+    }
+
     /// Sets an event handler with multiple methods for each possible event.
     pub fn event_handler<H: EventHandler + 'static>(mut self, event_handler: H) -> Self {
         self.event_handler = Some(Arc::new(event_handler));
@@ -332,6 +362,11 @@ impl<'a> ClientBuilder<'a> {
         self
     }
 
+    /// Gets the event handler, if already initialized. See [`Self::event_handler`] for more info.
+    pub fn get_event_handler(&self) -> Option<Arc<dyn EventHandler>> {
+        self.event_handler.clone()
+    }
+
     /// Sets an event handler with a single method where all received gateway
     /// events will be dispatched.
     pub fn raw_event_handler<H: RawEventHandler + 'static>(mut self, raw_event_handler: H) -> Self {
@@ -339,6 +374,12 @@ impl<'a> ClientBuilder<'a> {
 
         self
     }
+
+    /// Gets the raw event handler, if already initialized. See [`Self::raw_event_handler`] for more
+    /// info.
+    pub fn get_raw_event_handler(&self) -> Option<Arc<dyn RawEventHandler>> {
+        self.raw_event_handler.clone()
+    }
 }
 
 #[cfg(feature = "gateway")]
@@ -357,7 +398,7 @@ impl<'a> Future for ClientBuilder<'a> {
             let event_handler = self.event_handler.take();
             let raw_event_handler = self.raw_event_handler.take();
             let intents = self.intents;
-            let http = Arc::new(self.http.take().unwrap());
+            let http = Arc::new(std::mem::take(&mut self.http));
 
             #[cfg(feature = "unstable_discord_api")]
             if http.application_id == 0 {
@@ -571,7 +612,7 @@ pub struct Client {
     /// # async fn run() -> Result<(), Box<dyn std::error::Error>> {
     /// struct Handler;
     ///
-    /// impl EventHandler for Handler { }
+    /// impl EventHandler for Handler {}
     ///
     /// let token = std::env::var("DISCORD_TOKEN")?;
     /// let mut client = Client::builder(&token).event_handler(Handler).await?;
@@ -595,12 +636,13 @@ pub struct Client {
     ///
     /// ```rust,no_run
     /// # async fn run() -> Result<(), Box<dyn std::error::Error>> {
-    /// use serenity::client::{Client, EventHandler};
     /// use std::time::Duration;
     ///
+    /// use serenity::client::{Client, EventHandler};
+    ///
     /// struct Handler;
     ///
-    /// impl EventHandler for Handler { }
+    /// impl EventHandler for Handler {}
     ///
     /// let token = std::env::var("DISCORD_TOKEN")?;
     /// let mut client = Client::builder(&token).event_handler(Handler).await?;
