@@ -156,7 +156,7 @@ impl ComponentInteractionFilter {
     ) -> bool {
         // TODO: On next branch, switch filter arg to &T so this as_arc() call can be removed.
         self.options.guild_id.map_or(true, |id| Some(id) == interaction.guild_id.map(|g| g.0))
-            && self.options.message_id.map_or(true, |id| interaction.message.id().0 == id)
+            && self.options.message_id.map_or(true, |id| interaction.message.id.0 == id)
             && self.options.channel_id.map_or(true, |id| id == interaction.channel_id.as_ref().0)
             && self.options.author_id.map_or(true, |id| id == interaction.user.id.0)
             && self.options.filter.as_ref().map_or(true, |f| f(&interaction.as_arc()))
@@ -171,7 +171,7 @@ impl ComponentInteractionFilter {
     }
 }
 
-#[derive(Clone)]
+#[derive(Clone, Default)]
 struct FilterOptions {
     filter_limit: Option<u32>,
     collect_limit: Option<u32>,
@@ -194,20 +194,6 @@ impl std::fmt::Debug for FilterOptions {
     }
 }
 
-impl Default for FilterOptions {
-    fn default() -> Self {
-        Self {
-            filter_limit: None,
-            collect_limit: None,
-            filter: None,
-            channel_id: None,
-            guild_id: None,
-            author_id: None,
-            message_id: None,
-        }
-    }
-}
-
 // Implement the common setters for all component interaction collector types.
 // This avoids using a trait that the user would need to import in
 // order to use any of these methods.
