@@ -83,14 +83,14 @@ impl From<(bool, bool, bool)> for WithWhiteSpace {
 ///
 /// impl EventHandler for Handler {}
 ///
-/// use serenity::Client;
 /// use serenity::framework::StandardFramework;
 /// use serenity::model::id::UserId;
+/// use serenity::Client;
 ///
 /// # async fn run() -> Result<(), Box<dyn std::error::Error>> {
 /// let token = std::env::var("DISCORD_BOT_TOKEN")?;
-/// let framework = StandardFramework::new()
-///     .configure(|c| c.on_mention(Some(UserId(5))).prefix("~"));
+/// let framework =
+///     StandardFramework::new().configure(|c| c.on_mention(Some(UserId(5))).prefix("~"));
 ///
 /// let mut client = Client::builder(&token).event_handler(Handler).framework(framework).await?;
 /// #     Ok(())
@@ -193,11 +193,11 @@ impl Configuration {
     ///
     /// ```rust,no_run
     /// # use serenity::prelude::*;
-    /// use serenity::model::id::ChannelId;
     /// use serenity::framework::StandardFramework;
+    /// use serenity::model::id::ChannelId;
     ///
-    /// let framework = StandardFramework::new().configure(|c| c
-    ///     .allowed_channels(vec![ChannelId(7), ChannelId(77)].into_iter().collect()));
+    /// let framework = StandardFramework::new()
+    ///     .configure(|c| c.allowed_channels(vec![ChannelId(7), ChannelId(77)].into_iter().collect()));
     /// ```
     pub fn allowed_channels(&mut self, channels: HashSet<ChannelId>) -> &mut Self {
         self.allowed_channels = channels;
@@ -215,11 +215,11 @@ impl Configuration {
     ///
     /// ```rust,no_run
     /// # use serenity::prelude::*;
-    /// use serenity::model::id::GuildId;
     /// use serenity::framework::StandardFramework;
+    /// use serenity::model::id::GuildId;
     ///
-    /// let framework = StandardFramework::new().configure(|c| c
-    ///     .blocked_guilds(vec![GuildId(7), GuildId(77)].into_iter().collect()));
+    /// let framework = StandardFramework::new()
+    ///     .configure(|c| c.blocked_guilds(vec![GuildId(7), GuildId(77)].into_iter().collect()));
     /// ```
     pub fn blocked_guilds(&mut self, guilds: HashSet<GuildId>) -> &mut Self {
         self.blocked_guilds = guilds;
@@ -239,11 +239,11 @@ impl Configuration {
     ///
     /// ```rust,no_run
     /// # use serenity::prelude::*;
-    /// use serenity::model::id::UserId;
     /// use serenity::framework::StandardFramework;
+    /// use serenity::model::id::UserId;
     ///
-    /// let framework = StandardFramework::new().configure(|c| c
-    ///     .blocked_users(vec![UserId(7), UserId(77)].into_iter().collect()));
+    /// let framework = StandardFramework::new()
+    ///     .configure(|c| c.blocked_users(vec![UserId(7), UserId(77)].into_iter().collect()));
     /// ```
     pub fn blocked_users(&mut self, users: HashSet<UserId>) -> &mut Self {
         self.blocked_users = users;
@@ -260,11 +260,11 @@ impl Configuration {
     /// Ignore a set of commands, assuming they exist:
     ///
     /// ```rust,no_run
-    /// use serenity::framework::StandardFramework;
     /// use serenity::client::Context;
-    /// use serenity::model::channel::Message;
+    /// use serenity::framework::standard::macros::{command, group};
     /// use serenity::framework::standard::CommandResult;
-    /// use serenity::framework::standard::macros::{group, command};
+    /// use serenity::framework::StandardFramework;
+    /// use serenity::model::channel::Message;
     ///
     /// #[command]
     /// async fn ping(ctx: &Context, msg: &Message) -> CommandResult {
@@ -278,9 +278,8 @@ impl Configuration {
     ///
     /// let disabled = vec!["ping"].into_iter().map(|x| x.to_string()).collect();
     ///
-    /// let framework = StandardFramework::new()
-    ///     .group(&PENG_GROUP)
-    ///     .configure(|c| c.disabled_commands(disabled));
+    /// let framework =
+    ///     StandardFramework::new().group(&PENG_GROUP).configure(|c| c.disabled_commands(disabled));
     /// ```
     #[inline]
     pub fn disabled_commands(&mut self, commands: HashSet<String>) -> &mut Self {
@@ -317,14 +316,13 @@ impl Configuration {
     /// # use serenity::prelude::*;
     /// use serenity::framework::StandardFramework;
     ///
-    /// let framework = StandardFramework::new()
-    ///     .configure(|c| c.dynamic_prefix(|_, msg| Box::pin(async move {
-    ///         Some(if msg.channel_id.0 % 5 == 0 {
-    ///             "!"
-    ///         } else {
-    ///             "*"
-    ///         }.to_string())
-    ///     })));
+    /// let framework = StandardFramework::new().configure(|c| {
+    ///     c.dynamic_prefix(|_, msg| {
+    ///         Box::pin(
+    ///             async move { Some(if msg.channel_id.0 % 5 == 0 { "!" } else { "*" }.to_string()) },
+    ///         )
+    ///     })
+    /// });
     /// ```
     ///
     /// This will only use the prefix `"!"` or `"*"` depending on channel ID,
@@ -334,8 +332,8 @@ impl Configuration {
     /// # use serenity::prelude::*;
     /// use serenity::framework::StandardFramework;
     ///
-    /// let framework = StandardFramework::new()
-    ///     .configure(|c| c
+    /// let framework = StandardFramework::new().configure(|c| {
+    ///     c
     ///        .dynamic_prefix(|_, msg| Box::pin(async move {
     ///             Some(if msg.channel_id.0 % 5 == 0 {
     ///                 "!"
@@ -345,7 +343,7 @@ impl Configuration {
     ///         }))
     ///         // This disables the default prefix "~"
     ///         .prefix("")
-    ///     );
+    /// });
     /// ```
     ///
     /// [`Context::data`]: crate::client::Context::data
@@ -412,19 +410,20 @@ impl Configuration {
     /// Create a HashSet in-place:
     ///
     /// ```rust,no_run
-    /// use serenity::model::id::UserId;
     /// use serenity::framework::StandardFramework;
+    /// use serenity::model::id::UserId;
     ///
-    /// let framework = StandardFramework::new().configure(|c| c
-    ///     .owners(vec![UserId(7), UserId(77)].into_iter().collect()));
+    /// let framework = StandardFramework::new()
+    ///     .configure(|c| c.owners(vec![UserId(7), UserId(77)].into_iter().collect()));
     /// ```
     ///
     /// Create a HashSet beforehand:
     ///
     /// ```rust,no_run
-    /// use serenity::model::id::UserId;
     /// use std::collections::HashSet;
+    ///
     /// use serenity::framework::StandardFramework;
+    /// use serenity::model::id::UserId;
     ///
     /// let mut set = HashSet::new();
     /// set.insert(UserId(7));
@@ -455,11 +454,11 @@ impl Configuration {
     /// ```rust,no_run
     /// use serenity::framework::StandardFramework;
     ///
-    /// let framework = StandardFramework::new().configure(|c| c
-    ///     .prefix("!"));
+    /// let framework = StandardFramework::new().configure(|c| c.prefix("!"));
     /// ```
-    pub fn prefix(&mut self, prefix: &str) -> &mut Self {
-        self.prefixes = if prefix.is_empty() { vec![] } else { vec![prefix.to_string()] };
+    pub fn prefix(&mut self, prefix: impl ToString) -> &mut Self {
+        let p = prefix.to_string();
+        self.prefixes = if p.is_empty() { vec![] } else { vec![p] };
 
         self
     }
@@ -479,8 +478,7 @@ impl Configuration {
     /// ```rust,no_run
     /// use serenity::framework::StandardFramework;
     ///
-    /// let framework = StandardFramework::new().configure(|c| c
-    ///     .prefixes(vec!["!", ">", "+"]));
+    /// let framework = StandardFramework::new().configure(|c| c.prefixes(vec!["!", ">", "+"]));
     /// ```
     #[inline]
     pub fn prefixes<T, It>(&mut self, prefixes: It) -> &mut Self
@@ -488,7 +486,8 @@ impl Configuration {
         T: ToString,
         It: IntoIterator<Item = T>,
     {
-        self.prefixes = prefixes.into_iter().map(|p| p.to_string()).collect();
+        self.prefixes =
+            prefixes.into_iter().map(|p| p.to_string()).filter(|p| !p.is_empty()).collect();
 
         self
     }
@@ -518,8 +517,7 @@ impl Configuration {
     /// ```rust,no_run
     /// use serenity::framework::StandardFramework;
     ///
-    /// let framework = StandardFramework::new().configure(|c| c
-    ///     .delimiter(", "));
+    /// let framework = StandardFramework::new().configure(|c| c.delimiter(", "));
     /// ```
     pub fn delimiter<I: Into<Delimiter>>(&mut self, delimiter: I) -> &mut Self {
         self.delimiters.clear();
@@ -540,8 +538,7 @@ impl Configuration {
     /// ```rust,no_run
     /// use serenity::framework::StandardFramework;
     ///
-    /// let framework = StandardFramework::new().configure(|c| c
-    ///     .delimiters(vec![", ", " "]));
+    /// let framework = StandardFramework::new().configure(|c| c.delimiters(vec![", ", " "]));
     /// ```
     pub fn delimiters<T, It>(&mut self, delimiters: It) -> &mut Self
     where
