@@ -338,6 +338,12 @@ pub enum Route {
     ///
     /// [`GuildId`]: crate::model::id::GuildId
     GuildsIdWelcomeScreen(u64),
+    /// Route for the `/guilds/:guild_id/threads/active` path.
+    ///
+    /// The data is the relevant [`GuildId`].
+    ///
+    /// [`GuildId`]: crate::model::id::GuildId
+    GuildsIdThreadsActive,
     /// Route for the `/invites/:code` path.
     InvitesCode,
     /// Route for the `/users/:user_id` path.
@@ -368,7 +374,6 @@ pub enum Route {
     ///
     /// [`ApplicationId`]: crate::model::id::ApplicationId
     #[cfg(feature = "unstable_discord_api")]
-    #[cfg_attr(docsrs, doc(cfg(feature = "unstable_discord_api")))]
     WebhooksApplicationId(u64),
     /// Route for the `/interactions/:interaction_id` path.
     ///
@@ -376,7 +381,6 @@ pub enum Route {
     ///
     /// [`InteractionId`]: crate::model::id::InteractionId
     #[cfg(feature = "unstable_discord_api")]
-    #[cfg_attr(docsrs, doc(cfg(feature = "unstable_discord_api")))]
     InteractionsId(u64),
     /// Route for the `/applications/:application_id` path.
     ///
@@ -384,7 +388,6 @@ pub enum Route {
     ///
     /// [`ApplicationId`]: crate::model::id::ApplicationId
     #[cfg(feature = "unstable_discord_api")]
-    #[cfg_attr(docsrs, doc(cfg(feature = "unstable_discord_api")))]
     ApplicationsIdCommands(u64),
     /// Route for the `/applications/:application_id/commands/:command_id` path.
     ///
@@ -392,7 +395,6 @@ pub enum Route {
     ///
     /// [`ApplicationId`]: crate::model::id::ApplicationId
     #[cfg(feature = "unstable_discord_api")]
-    #[cfg_attr(docsrs, doc(cfg(feature = "unstable_discord_api")))]
     ApplicationsIdCommandsId(u64),
     /// Route for the `/applications/:application_id/guilds/:guild_id` path.
     ///
@@ -400,7 +402,6 @@ pub enum Route {
     ///
     /// [`ApplicationId`]: crate::model::id::ApplicationId
     #[cfg(feature = "unstable_discord_api")]
-    #[cfg_attr(docsrs, doc(cfg(feature = "unstable_discord_api")))]
     ApplicationsIdGuildsIdCommands(u64),
     /// Route for the `/applications/:application_id/guilds/:guild_id/commands/permissions` path.
     ///
@@ -408,7 +409,6 @@ pub enum Route {
     ///
     /// [`ApplicationId`]: crate::model::id::ApplicationId
     #[cfg(feature = "unstable_discord_api")]
-    #[cfg_attr(docsrs, doc(cfg(feature = "unstable_discord_api")))]
     ApplicationsIdGuildsIdCommandsPermissions(u64),
     /// Route for the `/applications/:application_id/guilds/:guild_id/commands/:command_id/permissions` path.
     ///
@@ -416,7 +416,6 @@ pub enum Route {
     ///
     /// [`ApplicationId`]: crate::model::id::ApplicationId
     #[cfg(feature = "unstable_discord_api")]
-    #[cfg_attr(docsrs, doc(cfg(feature = "unstable_discord_api")))]
     ApplicationsIdGuildsIdCommandIdPermissions(u64),
     /// Route for the `/applications/:application_id/guilds/:guild_id` path.
     ///
@@ -424,7 +423,6 @@ pub enum Route {
     ///
     /// [`ApplicationId`]: crate::model::id::ApplicationId
     #[cfg(feature = "unstable_discord_api")]
-    #[cfg_attr(docsrs, doc(cfg(feature = "unstable_discord_api")))]
     ApplicationsIdGuildsIdCommandsId(u64),
     /// Route for the `/stage-instances` path.
     ///
@@ -813,6 +811,10 @@ impl Route {
         format!(api!("/guilds/{}/welcome-screen"), guild_id)
     }
 
+    pub fn guild_threads_active(guild_id: u64) -> String {
+        format!(api!("/guilds/{}/threads/active"), guild_id)
+    }
+
     pub fn guilds() -> &'static str {
         api!("/guilds")
     }
@@ -917,7 +919,6 @@ impl Route {
     }
 
     #[cfg(feature = "unstable_discord_api")]
-    #[cfg_attr(docsrs, doc(cfg(feature = "unstable_discord_api")))]
     pub fn webhook_original_interaction_response<D: Display>(
         application_id: u64,
         token: D,
@@ -926,7 +927,6 @@ impl Route {
     }
 
     #[cfg(feature = "unstable_discord_api")]
-    #[cfg_attr(docsrs, doc(cfg(feature = "unstable_discord_api")))]
     pub fn webhook_followup_message<D: Display>(
         application_id: u64,
         token: D,
@@ -936,31 +936,26 @@ impl Route {
     }
 
     #[cfg(feature = "unstable_discord_api")]
-    #[cfg_attr(docsrs, doc(cfg(feature = "unstable_discord_api")))]
     pub fn webhook_followup_messages<D: Display>(application_id: u64, token: D) -> String {
         format!(api!("/webhooks/{}/{}"), application_id, token)
     }
 
     #[cfg(feature = "unstable_discord_api")]
-    #[cfg_attr(docsrs, doc(cfg(feature = "unstable_discord_api")))]
     pub fn interaction_response<D: Display>(application_id: u64, token: D) -> String {
         format!(api!("/interactions/{}/{}/callback"), application_id, token)
     }
 
     #[cfg(feature = "unstable_discord_api")]
-    #[cfg_attr(docsrs, doc(cfg(feature = "unstable_discord_api")))]
     pub fn application_command(application_id: u64, command_id: u64) -> String {
         format!(api!("/applications/{}/commands/{}"), application_id, command_id)
     }
 
     #[cfg(feature = "unstable_discord_api")]
-    #[cfg_attr(docsrs, doc(cfg(feature = "unstable_discord_api")))]
     pub fn application_commands(application_id: u64) -> String {
         format!(api!("/applications/{}/commands"), application_id)
     }
 
     #[cfg(feature = "unstable_discord_api")]
-    #[cfg_attr(docsrs, doc(cfg(feature = "unstable_discord_api")))]
     pub fn application_guild_command(
         application_id: u64,
         guild_id: u64,
@@ -973,7 +968,6 @@ impl Route {
     }
 
     #[cfg(feature = "unstable_discord_api")]
-    #[cfg_attr(docsrs, doc(cfg(feature = "unstable_discord_api")))]
     pub fn application_guild_command_permissions(
         application_id: u64,
         guild_id: u64,
@@ -986,13 +980,11 @@ impl Route {
     }
 
     #[cfg(feature = "unstable_discord_api")]
-    #[cfg_attr(docsrs, doc(cfg(feature = "unstable_discord_api")))]
     pub fn application_guild_commands(application_id: u64, guild_id: u64) -> String {
         format!(api!("/applications/{}/guilds/{}/commands"), application_id, guild_id)
     }
 
     #[cfg(feature = "unstable_discord_api")]
-    #[cfg_attr(docsrs, doc(cfg(feature = "unstable_discord_api")))]
     pub fn application_guild_commands_permissions(application_id: u64, guild_id: u64) -> String {
         format!(api!("/applications/{}/guilds/{}/commands/permissions"), application_id, guild_id)
     }
@@ -1038,30 +1030,25 @@ pub enum RouteInfo<'a> {
         guild_id: u64,
     },
     #[cfg(feature = "unstable_discord_api")]
-    #[cfg_attr(docsrs, doc(cfg(feature = "unstable_discord_api")))]
     CreateFollowupMessage {
         application_id: u64,
         interaction_token: &'a str,
     },
     #[cfg(feature = "unstable_discord_api")]
-    #[cfg_attr(docsrs, doc(cfg(feature = "unstable_discord_api")))]
     CreateGlobalApplicationCommand {
         application_id: u64,
     },
     #[cfg(feature = "unstable_discord_api")]
-    #[cfg_attr(docsrs, doc(cfg(feature = "unstable_discord_api")))]
     CreateGlobalApplicationCommands {
         application_id: u64,
     },
     CreateGuild,
     #[cfg(feature = "unstable_discord_api")]
-    #[cfg_attr(docsrs, doc(cfg(feature = "unstable_discord_api")))]
     CreateGuildApplicationCommand {
         application_id: u64,
         guild_id: u64,
     },
     #[cfg(feature = "unstable_discord_api")]
-    #[cfg_attr(docsrs, doc(cfg(feature = "unstable_discord_api")))]
     CreateGuildApplicationCommands {
         application_id: u64,
         guild_id: u64,
@@ -1071,7 +1058,6 @@ pub enum RouteInfo<'a> {
         integration_id: u64,
     },
     #[cfg(feature = "unstable_discord_api")]
-    #[cfg_attr(docsrs, doc(cfg(feature = "unstable_discord_api")))]
     CreateInteractionResponse {
         interaction_id: u64,
         interaction_token: &'a str,
@@ -1109,14 +1095,12 @@ pub enum RouteInfo<'a> {
         emoji_id: u64,
     },
     #[cfg(feature = "unstable_discord_api")]
-    #[cfg_attr(docsrs, doc(cfg(feature = "unstable_discord_api")))]
     DeleteFollowupMessage {
         application_id: u64,
         interaction_token: &'a str,
         message_id: u64,
     },
     #[cfg(feature = "unstable_discord_api")]
-    #[cfg_attr(docsrs, doc(cfg(feature = "unstable_discord_api")))]
     DeleteGlobalApplicationCommand {
         application_id: u64,
         command_id: u64,
@@ -1125,7 +1109,6 @@ pub enum RouteInfo<'a> {
         guild_id: u64,
     },
     #[cfg(feature = "unstable_discord_api")]
-    #[cfg_attr(docsrs, doc(cfg(feature = "unstable_discord_api")))]
     DeleteGuildApplicationCommand {
         application_id: u64,
         guild_id: u64,
@@ -1155,7 +1138,6 @@ pub enum RouteInfo<'a> {
         reaction: &'a str,
     },
     #[cfg(feature = "unstable_discord_api")]
-    #[cfg_attr(docsrs, doc(cfg(feature = "unstable_discord_api")))]
     DeleteOriginalInteractionResponse {
         application_id: u64,
         interaction_token: &'a str,
@@ -1197,14 +1179,12 @@ pub enum RouteInfo<'a> {
         emoji_id: u64,
     },
     #[cfg(feature = "unstable_discord_api")]
-    #[cfg_attr(docsrs, doc(cfg(feature = "unstable_discord_api")))]
     EditFollowupMessage {
         application_id: u64,
         interaction_token: &'a str,
         message_id: u64,
     },
     #[cfg(feature = "unstable_discord_api")]
-    #[cfg_attr(docsrs, doc(cfg(feature = "unstable_discord_api")))]
     EditGlobalApplicationCommand {
         application_id: u64,
         command_id: u64,
@@ -1213,21 +1193,18 @@ pub enum RouteInfo<'a> {
         guild_id: u64,
     },
     #[cfg(feature = "unstable_discord_api")]
-    #[cfg_attr(docsrs, doc(cfg(feature = "unstable_discord_api")))]
     EditGuildApplicationCommand {
         application_id: u64,
         guild_id: u64,
         command_id: u64,
     },
     #[cfg(feature = "unstable_discord_api")]
-    #[cfg_attr(docsrs, doc(cfg(feature = "unstable_discord_api")))]
     EditGuildApplicationCommandPermission {
         application_id: u64,
         guild_id: u64,
         command_id: u64,
     },
     #[cfg(feature = "unstable_discord_api")]
-    #[cfg_attr(docsrs, doc(cfg(feature = "unstable_discord_api")))]
     EditGuildApplicationCommandsPermissions {
         application_id: u64,
         guild_id: u64,
@@ -1260,13 +1237,11 @@ pub enum RouteInfo<'a> {
         guild_id: u64,
     },
     #[cfg(feature = "unstable_discord_api")]
-    #[cfg_attr(docsrs, doc(cfg(feature = "unstable_discord_api")))]
     GetOriginalInteractionResponse {
         application_id: u64,
         interaction_token: &'a str,
     },
     #[cfg(feature = "unstable_discord_api")]
-    #[cfg_attr(docsrs, doc(cfg(feature = "unstable_discord_api")))]
     EditOriginalInteractionResponse {
         application_id: u64,
         interaction_token: &'a str,
@@ -1279,6 +1254,9 @@ pub enum RouteInfo<'a> {
     EditRolePosition {
         guild_id: u64,
     },
+    EditThread {
+        channel_id: u64,
+    },
     EditVoiceState {
         guild_id: u64,
         user_id: u64,
@@ -1374,14 +1352,18 @@ pub enum RouteInfo<'a> {
         guild_id: u64,
         emoji_id: u64,
     },
+    #[cfg(feature = "unstable_discord_api")]
+    GetFollowupMessage {
+        application_id: u64,
+        interaction_token: &'a str,
+        message_id: u64,
+    },
     GetGateway,
     #[cfg(feature = "unstable_discord_api")]
-    #[cfg_attr(docsrs, doc(cfg(feature = "unstable_discord_api")))]
     GetGlobalApplicationCommands {
         application_id: u64,
     },
     #[cfg(feature = "unstable_discord_api")]
-    #[cfg_attr(docsrs, doc(cfg(feature = "unstable_discord_api")))]
     GetGlobalApplicationCommand {
         application_id: u64,
         command_id: u64,
@@ -1393,26 +1375,22 @@ pub enum RouteInfo<'a> {
         guild_id: u64,
     },
     #[cfg(feature = "unstable_discord_api")]
-    #[cfg_attr(docsrs, doc(cfg(feature = "unstable_discord_api")))]
     GetGuildApplicationCommands {
         application_id: u64,
         guild_id: u64,
     },
     #[cfg(feature = "unstable_discord_api")]
-    #[cfg_attr(docsrs, doc(cfg(feature = "unstable_discord_api")))]
     GetGuildApplicationCommand {
         application_id: u64,
         guild_id: u64,
         command_id: u64,
     },
     #[cfg(feature = "unstable_discord_api")]
-    #[cfg_attr(docsrs, doc(cfg(feature = "unstable_discord_api")))]
     GetGuildApplicationCommandsPermissions {
         application_id: u64,
         guild_id: u64,
     },
     #[cfg(feature = "unstable_discord_api")]
-    #[cfg_attr(docsrs, doc(cfg(feature = "unstable_discord_api")))]
     GetGuildApplicationCommandPermissions {
         application_id: u64,
         guild_id: u64,
@@ -1421,6 +1399,9 @@ pub enum RouteInfo<'a> {
     GetGuildWidget {
         guild_id: u64,
     },
+    GetGuildActiveThreads {
+        guild_id: u64,
+    },
     GetGuildPreview {
         guild_id: u64,
     },
@@ -2073,6 +2054,13 @@ impl<'a> RouteInfo<'a> {
                 Route::GuildsIdRolesId(guild_id),
                 Cow::from(Route::guild_roles(guild_id)),
             ),
+            RouteInfo::EditThread {
+                channel_id,
+            } => (
+                LightMethod::Patch,
+                Route::ChannelsId(channel_id),
+                Cow::from(Route::channel(channel_id)),
+            ),
             RouteInfo::EditVoiceState {
                 guild_id,
                 user_id,
@@ -2221,6 +2209,27 @@ impl<'a> RouteInfo<'a> {
                 Route::ChannelsIdMeJoindedArchivedPrivateThreads(channel_id),
                 Cow::from(Route::channel_joined_private_threads(channel_id, before, limit)),
             ),
+            #[cfg(feature = "unstable_discord_api")]
+            RouteInfo::GetFollowupMessage {
+                application_id,
+                interaction_token,
+                message_id,
+            } => (
+                LightMethod::Get,
+                Route::WebhooksApplicationId(application_id),
+                Cow::from(Route::webhook_followup_message(
+                    application_id,
+                    interaction_token,
+                    message_id,
+                )),
+            ),
+            RouteInfo::GetGuildActiveThreads {
+                guild_id,
+            } => (
+                LightMethod::Get,
+                Route::GuildsIdThreadsActive,
+                Cow::from(Route::guild_threads_active(guild_id)),
+            ),
             RouteInfo::JoinThread {
                 channel_id,
             } => (
