@@ -5,6 +5,7 @@ use std::sync::Arc;
 
 #[cfg(feature = "model")]
 use bytes::buf::Buf;
+#[cfg(feature = "model")]
 use futures::stream::Stream;
 #[cfg(feature = "model")]
 use reqwest::Url;
@@ -17,12 +18,14 @@ use tokio::{fs::File, io::AsyncReadExt};
 use crate::builder::{
     CreateInvite,
     CreateMessage,
+    CreateStageInstance,
     CreateThread,
     EditChannel,
     EditMessage,
+    EditStageInstance,
+    EditThread,
     GetMessages,
 };
-use crate::builder::{CreateStageInstance, EditStageInstance};
 #[cfg(all(feature = "cache", feature = "model"))]
 use crate::cache::Cache;
 #[cfg(feature = "collector")]
@@ -35,9 +38,7 @@ use crate::collector::{
     ReactionCollectorBuilder,
 };
 #[cfg(feature = "model")]
-use crate::http::AttachmentType;
-#[cfg(feature = "model")]
-use crate::http::{CacheHttp, Http, Typing};
+use crate::http::{AttachmentType, CacheHttp, Http, Typing};
 use crate::model::prelude::*;
 #[cfg(all(feature = "model", feature = "utils"))]
 use crate::utils;
@@ -511,17 +512,13 @@ impl ChannelId {
     /// # async fn run() {
     /// # let channel_id = ChannelId::default();
     /// # let ctx = Http::default();
-    /// use serenity::model::channel::MessagesIter;
     /// use serenity::futures::StreamExt;
+    /// use serenity::model::channel::MessagesIter;
     ///
     /// let mut messages = channel_id.messages_iter(&ctx).boxed();
     /// while let Some(message_result) = messages.next().await {
     ///     match message_result {
-    ///         Ok(message) => println!(
-    ///             "{} said \"{}\".",
-    ///             message.author.name,
-    ///             message.content,
-    ///         ),
+    ///         Ok(message) => println!("{} said \"{}\".", message.author.name, message.content,),
     ///         Err(error) => eprintln!("Uh oh! Error: {}", error),
     ///     }
     /// }
@@ -656,7 +653,9 @@ impl ChannelId {
     ///
     /// The [Attach Files] and [Send Messages] permissions are required.
     ///
-    /// **Note**: Message contents must be under 2000 unicode code points.
+    /// **Note**: Message contents must be under 2000 unicode code points, and embeds must be under
+    /// 6000 unicode code points.
+    ///
     ///
     /// # Examples
     ///
@@ -674,10 +673,7 @@ impl ChannelId {
     ///
     /// let paths = vec!["/path/to/file.jpg", "path/to/file2.jpg"];
     ///
-    /// let _ = channel_id.send_files(&http, paths, |m| {
-    ///     m.content("a file")
-    /// })
-    /// .await;
+    /// let _ = channel_id.send_files(&http, paths, |m| m.content("a file")).await;
     /// # }
     /// ```
     ///
@@ -699,10 +695,7 @@ impl ChannelId {
     ///
     /// let files = vec![(&f1, "my_file.jpg"), (&f2, "my_file2.jpg")];
     ///
-    /// let _ = channel_id.send_files(&http, files, |m| {
-    ///     m.content("a file")
-    /// })
-    /// .await;
+    /// let _ = channel_id.send_files(&http, files, |m| m.content("a file")).await;
     /// #    Ok(())
     /// # }
     /// ```
@@ -942,7 +935,6 @@ impl ChannelId {
 
     /// Returns a future that will await one message sent in this channel.
     #[cfg(feature = "collector")]
-    #[cfg_attr(docsrs, doc(cfg(feature = "collector")))]
     pub fn await_reply<'a>(
         &self,
         shard_messenger: &'a impl AsRef<ShardMessenger>,
@@ -952,7 +944,6 @@ impl ChannelId {
 
     /// Returns a stream builder which can be awaited to obtain a stream of messages in this channel.
     #[cfg(feature = "collector")]
-    #[cfg_attr(docsrs, doc(cfg(feature = "collector")))]
     pub fn await_replies<'a>(
         &self,
         shard_messenger: &'a impl AsRef<ShardMessenger>,
@@ -962,7 +953,6 @@ impl ChannelId {
 
     /// Await a single reaction in this guild.
     #[cfg(feature = "collector")]
-    #[cfg_attr(docsrs, doc(cfg(feature = "collector")))]
     pub fn await_reaction<'a>(
         &self,
         shard_messenger: &'a impl AsRef<ShardMessenger>,
@@ -972,7 +962,6 @@ impl ChannelId {
 
     /// Returns a stream builder which can be awaited to obtain a stream of reactions sent in this channel.
     #[cfg(feature = "collector")]
-    #[cfg_attr(docsrs, doc(cfg(feature = "collector")))]
     pub fn await_reactions<'a>(
         &self,
         shard_messenger: &'a impl AsRef<ShardMessenger>,
@@ -1034,6 +1023,23 @@ impl ChannelId {
         http.as_ref().edit_stage_instance(self.0, &Value::Object(map)).await
     }
 
+    /// Edits a thread.
+    ///
+    /// # Errors
+    ///
+    /// Returns [`Error::Http`] if the current user lacks permission.
+    pub async fn edit_thread<F>(&self, http: impl AsRef<Http>, f: F) -> Result<GuildChannel>
+    where
+        F: FnOnce(&mut EditThread) -> &mut EditThread,
+    {
+        let mut instance = EditThread::default();
+        f(&mut instance);
+
+        let map = utils::hashmap_to_json_map(instance.0);
+
+        http.as_ref().edit_thread(self.0, &map).await
+    }
+
     /// Deletes a stage instance.
     ///
     /// # Errors
@@ -1143,7 +1149,9 @@ impl ChannelId {
     ///
     /// It may return an [`Error::Http`] if the bot doesn't have the
     /// permission to get it.
+    #[deprecated(note = "Use GuildId::get_active_threads instead")]
     pub async fn get_active_threads(&self, http: impl AsRef<Http>) -> Result<ThreadsData> {
+        #[allow(deprecated)]
         http.as_ref().get_channel_active_threads(self.0).await
     }
 
@@ -1193,6 +1201,7 @@ impl ChannelId {
     }
 }
 
+#[cfg(feature = "model")]
 impl From<Channel> for ChannelId {
     /// Gets the Id of a [`Channel`].
     fn from(channel: Channel) -> ChannelId {
@@ -1200,6 +1209,7 @@ impl From<Channel> for ChannelId {
     }
 }
 
+#[cfg(feature = "model")]
 impl<'a> From<&'a Channel> for ChannelId {
     /// Gets the Id of a [`Channel`].
     fn from(channel: &Channel) -> ChannelId {
@@ -1317,17 +1327,13 @@ impl<H: AsRef<Http>> MessagesIter<H> {
     /// # async fn run() {
     /// # let channel_id = ChannelId::default();
     /// # let ctx = Http::default();
-    /// use serenity::model::channel::MessagesIter;
     /// use serenity::futures::StreamExt;
+    /// use serenity::model::channel::MessagesIter;
     ///
     /// let mut messages = MessagesIter::<Http>::stream(&ctx, channel_id).boxed();
     /// while let Some(message_result) = messages.next().await {
     ///     match message_result {
-    ///         Ok(message) => println!(
-    ///             "{} said \"{}\"",
-    ///             message.author.name,
-    ///             message.content,
-    ///         ),
+    ///         Ok(message) => println!("{} said \"{}\"", message.author.name, message.content,),
     ///         Err(error) => eprintln!("Uh oh! Error: {}", error),
     ///     }
     /// }
