@@ -13,12 +13,14 @@ use crate::builder::EditChannel;
 use crate::builder::{
     CreateInvite,
     CreateMessage,
+    CreateStageInstance,
     CreateThread,
     EditMessage,
+    EditStageInstance,
+    EditThread,
     EditVoiceState,
     GetMessages,
 };
-use crate::builder::{CreateStageInstance, EditStageInstance};
 #[cfg(feature = "cache")]
 use crate::cache::Cache;
 #[cfg(feature = "collector")]
@@ -105,6 +107,8 @@ pub struct GuildChannel {
     ///
     /// **Note**: This is only available for text channels excluding news
     /// channels.
+    #[doc(alias = "slowmode")]
+    #[deprecated(note = "will be renamed to `rate_limit_per_user` with serenity 0.11")]
     #[serde(default, rename = "rate_limit_per_user")]
     pub slow_mode_rate: Option<u64>,
     /// The region override.
@@ -229,23 +233,17 @@ impl GuildChannel {
     /// #     let cache = Cache::default();
     /// #     let (channel_id, user_id) = (ChannelId(0), UserId(0));
     /// #
-    /// use serenity::model::channel::{
-    ///     PermissionOverwrite,
-    ///     PermissionOverwriteType,
-    /// };
+    /// use serenity::model::channel::{PermissionOverwrite, PermissionOverwriteType};
     /// use serenity::model::{ModelError, Permissions};
     /// let allow = Permissions::SEND_MESSAGES;
     /// let deny = Permissions::SEND_TTS_MESSAGES | Permissions::ATTACH_FILES;
     /// let overwrite = PermissionOverwrite {
-    ///     allow: allow,
-    ///     deny: deny,
+    ///     allow,
+    ///     deny,
     ///     kind: PermissionOverwriteType::Member(user_id),
     /// };
     /// // assuming the cache has been unlocked
-    /// let channel = cache
-    ///     .guild_channel(channel_id)
-    ///     .await
-    ///     .ok_or(ModelError::ItemMissing)?;
+    /// let channel = cache.guild_channel(channel_id).await.ok_or(ModelError::ItemMissing)?;
     ///
     /// channel.create_permission(&http, &overwrite).await?;
     /// #   Ok(())
@@ -268,24 +266,18 @@ impl GuildChannel {
     /// #   let cache = Cache::default();
     /// #   let (channel_id, user_id) = (ChannelId(0), UserId(0));
     /// #
-    /// use serenity::model::channel::{
-    ///     PermissionOverwrite,
-    ///     PermissionOverwriteType,
-    /// };
-    /// use serenity::model::{ModelError, Permissions, channel::Channel};
+    /// use serenity::model::channel::{PermissionOverwrite, PermissionOverwriteType};
+    /// use serenity::model::{channel::Channel, ModelError, Permissions};
     ///
     /// let allow = Permissions::SEND_MESSAGES;
     /// let deny = Permissions::SEND_TTS_MESSAGES | Permissions::ATTACH_FILES;
     /// let overwrite = PermissionOverwrite {
-    ///     allow: allow,
-    ///     deny: deny,
+    ///     allow,
+    ///     deny,
     ///     kind: PermissionOverwriteType::Member(user_id),
     /// };
     ///
-    /// let channel = cache
-    ///     .guild_channel(channel_id)
-    ///     .await
-    ///     .ok_or(ModelError::ItemMissing)?;
+    /// let channel = cache.guild_channel(channel_id).await.ok_or(ModelError::ItemMissing)?;
     ///
     /// channel.create_permission(&http, &overwrite).await?;
     /// #     Ok(())
@@ -485,6 +477,18 @@ impl GuildChannel {
         self.id.edit_message(&http, message_id, f).await
     }
 
+    /// Edits a thread.
+    ///
+    /// # Errors
+    ///
+    /// Returns [`Error::Http`] if the current user lacks permission.
+    pub async fn edit_thread<F>(&self, http: impl AsRef<Http>, f: F) -> Result<GuildChannel>
+    where
+        F: FnOnce(&mut EditThread) -> &mut EditThread,
+    {
+        self.id.edit_thread(http, f).await
+    }
+
     /// Edits a voice state in a stage channel. Pass [`None`] for `user_id` to
     /// edit the current user's voice state.
     ///
@@ -701,8 +705,8 @@ impl GuildChannel {
     /// channel:
     ///
     /// ```rust,no_run
-    /// use serenity::prelude::*;
     /// use serenity::model::prelude::*;
+    /// use serenity::prelude::*;
     /// struct Handler;
     ///
     /// #[serenity::async_trait]
@@ -713,14 +717,15 @@ impl GuildChannel {
     ///             None => return,
     ///         };
     ///
-    ///         if let Ok(permissions) = channel.permissions_for_user(&context.cache, &msg.author).await {
+    ///         if let Ok(permissions) = channel.permissions_for_user(&context.cache, &msg.author).await
+    ///         {
     ///             println!("The user's permissions: {:?}", permissions);
     ///         }
     ///     }
     /// }
     ///
     /// # async fn run() -> Result<(), Box<dyn std::error::Error>> {
-    /// let mut client =Client::builder("token").event_handler(Handler).await?;
+    /// let mut client = Client::builder("token").event_handler(Handler).await?;
     ///
     /// client.start().await?;
     /// #     Ok(())
@@ -732,9 +737,9 @@ impl GuildChannel {
     /// for demonstrative purposes):
     ///
     /// ```rust,no_run
-    /// use serenity::prelude::*;
-    /// use serenity::model::prelude::*;
     /// use serenity::model::channel::Channel;
+    /// use serenity::model::prelude::*;
+    /// use serenity::prelude::*;
     /// use tokio::fs::File;
     ///
     /// struct Handler;
@@ -748,8 +753,9 @@ impl GuildChannel {
     ///         };
     ///
     ///         let current_user_id = context.cache.current_user().await.id;
-    ///         if let Ok(permissions) = channel.permissions_for_user(&context.cache, current_user_id).await {
-    ///
+    ///         if let Ok(permissions) =
+    ///             channel.permissions_for_user(&context.cache, current_user_id).await
+    ///         {
     ///             if !permissions.contains(Permissions::ATTACH_FILES | Permissions::SEND_MESSAGES) {
     ///                 return;
     ///             }
@@ -763,17 +769,19 @@ impl GuildChannel {
     ///                 },
     ///             };
     ///
-    ///             let _ = msg.channel_id.send_files(&context.http, vec![(&file, "cat.png")], |mut m| {
-    ///                 m.content("here's a cat");
-    ///                 m
-    ///             })
-    ///             .await;
+    ///             let _ = msg
+    ///                 .channel_id
+    ///                 .send_files(&context.http, vec![(&file, "cat.png")], |mut m| {
+    ///                     m.content("here's a cat");
+    ///                     m
+    ///                 })
+    ///                 .await;
     ///         }
     ///     }
     /// }
     ///
     /// # async fn run() -> Result<(), Box<dyn std::error::Error>> {
-    /// let mut client =Client::builder("token").event_handler(Handler).await?;
+    /// let mut client = Client::builder("token").event_handler(Handler).await?;
     ///
     /// client.start().await?;
     /// #     Ok(())
@@ -1111,7 +1119,6 @@ impl GuildChannel {
 
     /// Returns a future that will await one message by this guild channel.
     #[cfg(feature = "collector")]
-    #[cfg_attr(docsrs, doc(cfg(feature = "collector")))]
     pub fn await_reply<'a>(
         &self,
         shard_messenger: &'a impl AsRef<ShardMessenger>,
@@ -1121,7 +1128,6 @@ impl GuildChannel {
 
     /// Returns a stream builder which can be awaited to obtain a stream of messages sent by this guild channel.
     #[cfg(feature = "collector")]
-    #[cfg_attr(docsrs, doc(cfg(feature = "collector")))]
     pub fn await_replies<'a>(
         &self,
         shard_messenger: &'a impl AsRef<ShardMessenger>,
@@ -1131,7 +1137,6 @@ impl GuildChannel {
 
     /// Await a single reaction by this guild channel.
     #[cfg(feature = "collector")]
-    #[cfg_attr(docsrs, doc(cfg(feature = "collector")))]
     pub fn await_reaction<'a>(
         &self,
         shard_messenger: &'a impl AsRef<ShardMessenger>,
@@ -1141,7 +1146,6 @@ impl GuildChannel {
 
     /// Returns a stream builder which can be awaited to obtain a stream of reactions sent by this guild channel.
     #[cfg(feature = "collector")]
-    #[cfg_attr(docsrs, doc(cfg(feature = "collector")))]
     pub fn await_reactions<'a>(
         &self,
         shard_messenger: &'a impl AsRef<ShardMessenger>,
