@@ -1,5 +1,6 @@
 //! Models relating to Discord channels.
 
+#[cfg(feature = "model")]
 use std::fmt::Display;
 #[cfg(all(feature = "cache", feature = "model"))]
 use std::fmt::Write;
@@ -126,11 +127,9 @@ pub struct Message {
     ///
     /// [`Interaction`]: crate::model::interactions::Interaction
     #[cfg(feature = "unstable_discord_api")]
-    #[cfg_attr(docsrs, doc(cfg(feature = "unstable_discord_api")))]
     pub interaction: Option<MessageInteraction>,
     /// The components of this message
     #[cfg(feature = "unstable_discord_api")]
-    #[cfg_attr(docsrs, doc(cfg(feature = "unstable_discord_api")))]
     #[serde(default)]
     pub components: Vec<ActionRow>,
 }
@@ -151,7 +150,7 @@ impl Message {
     ///
     /// Returns a [`ModelError::MessageAlreadyCrossposted`] if the message has already been crossposted.
     ///
-    /// Returns a [`ModelError`::CannotCrosspostMessage`] if the message cannot be crossposted.
+    /// Returns a [`ModelError::CannotCrosspostMessage`] if the message cannot be crossposted.
     ///
     /// [Manage Messages]: Permissions::MANAGE_MESSAGES
     pub async fn crosspost(&self, cache_http: impl CacheHttp) -> Result<Message> {
@@ -877,7 +876,6 @@ impl Message {
 
     /// Await a single reaction on this message.
     #[cfg(feature = "collector")]
-    #[cfg_attr(docsrs, doc(cfg(feature = "collector")))]
     pub fn await_reaction<'a>(
         &self,
         shard_messenger: &'a impl AsRef<ShardMessenger>,
@@ -887,7 +885,6 @@ impl Message {
 
     /// Returns a stream builder which can be awaited to obtain a stream of reactions on this message.
     #[cfg(feature = "collector")]
-    #[cfg_attr(docsrs, doc(cfg(feature = "collector")))]
     pub fn await_reactions<'a>(
         &self,
         shard_messenger: &'a impl AsRef<ShardMessenger>,
@@ -897,7 +894,6 @@ impl Message {
 
     /// Await a single component interaction on this message.
     #[cfg(all(feature = "unstable_discord_api", feature = "collector"))]
-    #[cfg_attr(docsrs, doc(cfg(all(feature = "unstable_discord_api", feature = "collector"))))]
     pub fn await_component_interaction<'a>(
         &self,
         shard_messenger: &'a impl AsRef<ShardMessenger>,
@@ -907,7 +903,6 @@ impl Message {
 
     /// Returns a stream builder which can be awaited to obtain a stream of component interactions on this message.
     #[cfg(all(feature = "unstable_discord_api", feature = "collector"))]
-    #[cfg_attr(docsrs, doc(cfg(all(feature = "unstable_discord_api", feature = "collector"))))]
     pub fn await_component_interactions<'a>(
         &self,
         shard_messenger: &'a impl AsRef<ShardMessenger>,
@@ -1070,11 +1065,14 @@ pub enum MessageType {
     /// A message reply.
     InlineReply = 19,
     /// A slash command.
+    // TODO: Rename to chat input command in next
     ApplicationCommand = 20,
     /// A thread start message.
     ThreadStarterMessage = 21,
     /// Server setup tips.
     GuildInviteReminder = 22,
+    /// A context menu command.
+    ContextMenuCommand = 23,
     /// An indicator that the message is of unknown type.
     Unknown = !0,
 }
@@ -1101,7 +1099,8 @@ enum_number!(MessageType {
     InlineReply,
     ApplicationCommand,
     ThreadStarterMessage,
-    GuildInviteReminder
+    GuildInviteReminder,
+    ContextMenuCommand,
 });
 
 #[derive(Clone, Copy, Debug, Eq, Hash, PartialEq, PartialOrd, Ord)]
@@ -1209,21 +1208,21 @@ pub struct MessageFlags {
 __impl_bitflags! {
     MessageFlags: u64 {
         /// This message has been published to subscribed channels (via Channel Following).
-        CROSSPOSTED = 0b0000_0000_0000_0000_0000_0000_0000_0001;
+        CROSSPOSTED = 1 << 0;
         /// This message originated from a message in another channel (via Channel Following).
-        IS_CROSSPOST = 0b0000_0000_0000_0000_0000_0000_0000_0010;
+        IS_CROSSPOST = 1 << 1;
         /// Do not include any embeds when serializing this message.
-        SUPPRESS_EMBEDS = 0b0000_0000_0000_0000_0000_0000_0000_0100;
+        SUPPRESS_EMBEDS = 1 << 2;
         /// The source message for this crosspost has been deleted (via Channel Following).
-        SOURCE_MESSAGE_DELETED = 0b0000_0000_0000_0000_0000_0000_0000_1000;
+        SOURCE_MESSAGE_DELETED = 1 << 3;
         /// This message came from the urgent message system.
-        URGENT = 0b0000_0000_0000_0000_0000_0000_0001_0000;
+        URGENT = 1 << 4;
         /// This message has an associated thread, with the same id as the message.
-        HAS_THREAD = 0b0000_0000_0000_0000_0000_0000_0010_0000;
+        HAS_THREAD = 1 << 5;
         /// This message is only visible to the user who invoked the Interaction.
-        EPHEMERAL = 0b0000_0000_0000_0000_0000_0000_0100_0000;
+        EPHEMERAL = 1 << 6;
         /// This message is an Interaction Response and the bot is "thinking".
-        LOADING = 0b0000_0000_0000_0000_0000_0000_1000_0000;
+        LOADING = 1 << 7;
     }
 }
 
