@@ -37,6 +37,7 @@ use crate::cache::Cache;
 use crate::cache::FromStrAndCache;
 #[cfg(feature = "model")]
 use crate::http::CacheHttp;
+use crate::internal::is_false;
 #[cfg(all(feature = "cache", feature = "model", feature = "utils"))]
 use crate::model::misc::ChannelParseError;
 use crate::model::prelude::*;
@@ -86,7 +87,9 @@ impl Channel {
     ///     Some(guild_channel) => {
     ///         println!("It's a guild channel named {}!", guild_channel.name);
     ///     },
-    ///     None => { println!("It's not in a guild!"); },
+    ///     None => {
+    ///         println!("It's not in a guild!");
+    ///     },
     /// }
     /// # }
     /// ```
@@ -121,7 +124,9 @@ impl Channel {
     ///     Some(private) => {
     ///         println!("It's a private channel with {}!", &private.recipient);
     ///     },
-    ///     None => { println!("It's not a private channel!"); },
+    ///     None => {
+    ///         println!("It's not a private channel!");
+    ///     },
     /// }
     /// # }
     /// ```
@@ -156,7 +161,9 @@ impl Channel {
     ///     Some(category) => {
     ///         println!("It's a category named {}!", category.name);
     ///     },
-    ///     None => { println!("It's not a category!"); },
+    ///     None => {
+    ///         println!("It's not a category!");
+    ///     },
     /// }
     /// #
     /// # }
@@ -295,6 +302,7 @@ impl Display for Channel {
 /// A representation of a type of channel.
 #[derive(Clone, Copy, Debug, Eq, Hash, PartialEq, PartialOrd, Ord)]
 #[non_exhaustive]
+#[repr(u8)]
 pub enum ChannelType {
     /// An indicator that the channel is a text [`GuildChannel`].
     Text = 0,
@@ -472,6 +480,15 @@ pub struct ThreadMetadata {
     /// When a thread is locked, only users with `MANAGE_THREADS` permission can unarchive it.
     #[serde(default)]
     pub locked: bool,
+    /// Timestamp when the thread was created.
+    ///
+    /// **Note**: only populated for threads created after 2022-01-09
+    pub create_timestamp: Option<DateTime<Utc>>,
+    /// Whether non-moderators can add other non-moderators to a thread.
+    ///
+    /// **Note**: Only available on private threads.
+    #[serde(default, skip_serializing_if = "is_false")]
+    pub invitable: bool,
 }
 
 /// A response to getting several threads channels.
@@ -483,6 +500,7 @@ pub struct ThreadsData {
     /// A thread member for each returned thread the current user has joined.
     pub members: Vec<ThreadMember>,
     /// Whether there are potentially additional threads that could be returned on a subsequent call.
+    #[serde(default)]
     pub has_more: bool,
 }
 
@@ -531,6 +549,8 @@ mod test {
                     discriminator: 1,
                     name: "ab".to_string(),
                     public_flags: None,
+                    banner: None,
+                    accent_colour: None,
                 },
             }
         }
