@@ -1,5 +1,8 @@
 //! Models pertaining to the gateway.
 
+// TODO: Remove after `GuildStatus` was replaced
+#![allow(deprecated)]
+
 use bitflags::bitflags;
 use serde::de::Error as DeError;
 use serde::ser::{Serialize, SerializeStruct, Serializer};
@@ -58,13 +61,11 @@ pub struct Activity {
     /// The sync ID of the activity. Mainly used by the Spotify activity
     /// type which uses this parameter to store the track ID.
     #[cfg(feature = "unstable_discord_api")]
-    #[cfg_attr(docsrs, doc(cfg(feature = "unstable_discord_api")))]
     pub sync_id: Option<String>,
     /// The session ID of the activity. Reserved for specific activity
     /// types, such as the Activity that is transmitted when a user is
     /// listening to Spotify.
     #[cfg(feature = "unstable_discord_api")]
-    #[cfg_attr(docsrs, doc(cfg(feature = "unstable_discord_api")))]
     pub session_id: Option<String>,
     /// The Stream URL if [`Self::kind`] is [`ActivityType::Streaming`].
     pub url: Option<String>,
@@ -86,12 +87,12 @@ impl Activity {
     /// Create a command that sets the current activity:
     ///
     /// ```rust,no_run
-    /// use serenity::model::gateway::Activity;
-    /// use serenity::model::channel::Message;
-    /// # #[cfg(feature = "framework")]
-    /// use serenity::framework::standard::{Args, CommandResult, macros::command};
     /// # #[cfg(feature = "client")]
     /// use serenity::client::Context;
+    /// # #[cfg(feature = "framework")]
+    /// use serenity::framework::standard::{macros::command, Args, CommandResult};
+    /// use serenity::model::channel::Message;
+    /// use serenity::model::gateway::Activity;
     ///
     /// # #[cfg(feature = "framework")]
     /// #[command]
@@ -138,12 +139,12 @@ impl Activity {
     /// Create a command that sets the current streaming status:
     ///
     /// ```rust,no_run
-    /// use serenity::model::gateway::Activity;
-    /// use serenity::model::channel::Message;
-    /// # #[cfg(feature = "framework")]
-    /// use serenity::framework::standard::{Args, CommandResult, macros::command};
     /// # #[cfg(feature = "client")]
     /// use serenity::client::Context;
+    /// # #[cfg(feature = "framework")]
+    /// use serenity::framework::standard::{macros::command, Args, CommandResult};
+    /// use serenity::model::channel::Message;
+    /// use serenity::model::gateway::Activity;
     ///
     /// # #[cfg(feature = "framework")]
     /// #[command]
@@ -192,12 +193,12 @@ impl Activity {
     /// Create a command that sets the current listening status:
     ///
     /// ```rust,no_run
-    /// use serenity::model::gateway::Activity;
-    /// use serenity::model::channel::Message;
-    /// # #[cfg(feature = "framework")]
-    /// use serenity::framework::standard::{Args, CommandResult, macros::command};
     /// # #[cfg(feature = "client")]
     /// use serenity::client::Context;
+    /// # #[cfg(feature = "framework")]
+    /// use serenity::framework::standard::{macros::command, Args, CommandResult};
+    /// use serenity::model::channel::Message;
+    /// use serenity::model::gateway::Activity;
     ///
     /// # #[cfg(feature = "framework")]
     /// #[command]
@@ -243,12 +244,12 @@ impl Activity {
     /// Create a command that sets the current cometing status:
     ///
     /// ```rust,no_run
-    /// use serenity::model::gateway::Activity;
-    /// use serenity::model::channel::Message;
-    /// # #[cfg(feature = "framework")]
-    /// use serenity::framework::standard::{Args, CommandResult, macros::command};
     /// # #[cfg(feature = "client")]
     /// use serenity::client::Context;
+    /// # #[cfg(feature = "framework")]
+    /// use serenity::framework::standard::{macros::command, Args, CommandResult};
+    /// use serenity::model::channel::Message;
+    /// use serenity::model::gateway::Activity;
     ///
     /// # #[cfg(feature = "framework")]
     /// #[command]
@@ -294,12 +295,12 @@ impl Activity {
     /// Create a command that sets the current cometing status:
     ///
     /// ```rust,no_run
-    /// use serenity::model::gateway::Activity;
-    /// use serenity::model::channel::Message;
-    /// # #[cfg(feature = "framework")]
-    /// use serenity::framework::standard::{Args, CommandResult, macros::command};
     /// # #[cfg(feature = "client")]
     /// use serenity::client::Context;
+    /// # #[cfg(feature = "framework")]
+    /// use serenity::framework::standard::{macros::command, Args, CommandResult};
+    /// use serenity::model::channel::Message;
+    /// use serenity::model::gateway::Activity;
     ///
     /// # #[cfg(feature = "framework")]
     /// #[command]
@@ -480,17 +481,23 @@ bitflags! {
     #[derive(Deserialize, Serialize)]
     pub struct ActivityFlags: u64 {
         /// Whether the activity is an instance activity.
-        const INSTANCE = 0b001;
+        const INSTANCE = 1 << 0;
         /// Whether the activity is joinable.
-        const JOIN = 0b010;
+        const JOIN = 1 << 1;
         /// Whether the activity can be spectated.
-        const SPECTATE = 0b011;
+        const SPECTATE = 1 << 2;
         /// Whether a request can be sent to join the user's party.
-        const JOIN_REQUEST = 0b100;
+        const JOIN_REQUEST = 1 << 3;
         /// Whether the activity can be synced.
-        const SYNC = 0b101;
+        const SYNC = 1 << 4;
         /// Whether the activity can be played.
-        const PLAY = 0b110;
+        const PLAY = 1 << 5;
+        /// Whether the activity party is friend only.
+        const PARTY_PRIVACY_FRIENDS = 1 << 6;
+        /// Whether the activity party is in a voice channel.
+        const PARTY_PRIVACY_VOICE_CHANNEL = 1 << 7;
+        /// Whether the activity can be embedded.
+        const EMBEDDED = 1 << 8;
     }
 }
 
