@@ -1,3 +1,4 @@
+#[cfg(feature = "model")]
 use futures::stream::Stream;
 #[cfg(feature = "model")]
 use serde_json::json;
@@ -49,8 +50,8 @@ impl GuildId {
     /// Ban a member and remove all messages they've sent in the last 4 days:
     ///
     /// ```rust,no_run
-    /// use serenity::model::id::UserId;
     /// use serenity::model::id::GuildId;
+    /// use serenity::model::id::UserId;
     ///
     /// # async fn run() -> Result<(), Box<dyn std::error::Error>> {
     /// # use serenity::http::Http;
@@ -183,13 +184,14 @@ impl GuildId {
     /// Create a voice channel in a guild with the name `test`:
     ///
     /// ```rust,no_run
-    /// use serenity::model::id::GuildId;
     /// use serenity::model::channel::ChannelType;
+    /// use serenity::model::id::GuildId;
     ///
     /// # async fn run() {
     /// # use serenity::http::Http;
     /// # let http = Http::default();
-    /// let _channel = GuildId(7).create_channel(&http, |c| c.name("test").kind(ChannelType::Voice)).await;
+    /// let _channel =
+    ///     GuildId(7).create_channel(&http, |c| c.name("test").kind(ChannelType::Voice)).await;
     /// # }
     /// ```
     ///
@@ -827,17 +829,13 @@ impl GuildId {
     /// # async fn run() {
     /// # let guild_id = GuildId::default();
     /// # let ctx = Http::default();
-    /// use serenity::model::guild::MembersIter;
     /// use serenity::futures::StreamExt;
+    /// use serenity::model::guild::MembersIter;
     ///
     /// let mut members = guild_id.members_iter(&ctx).boxed();
     /// while let Some(member_result) = members.next().await {
     ///     match member_result {
-    ///         Ok(member) => println!(
-    ///             "{} is {}",
-    ///             member,
-    ///             member.display_name(),
-    ///         ),
+    ///         Ok(member) => println!("{} is {}", member, member.display_name(),),
     ///         Err(error) => eprintln!("Uh oh!  Error: {}", error),
     ///     }
     /// }
@@ -1107,7 +1105,6 @@ impl GuildId {
 
     /// Returns a future that will await one message sent in this guild.
     #[cfg(feature = "collector")]
-    #[cfg_attr(docsrs, doc(cfg(feature = "collector")))]
     pub fn await_reply<'a>(
         &self,
         shard_messenger: &'a impl AsRef<ShardMessenger>,
@@ -1117,7 +1114,6 @@ impl GuildId {
 
     /// Returns a stream builder which can be awaited to obtain a stream of messages in this guild.
     #[cfg(feature = "collector")]
-    #[cfg_attr(docsrs, doc(cfg(feature = "collector")))]
     pub fn await_replies<'a>(
         &self,
         shard_messenger: &'a impl AsRef<ShardMessenger>,
@@ -1127,7 +1123,6 @@ impl GuildId {
 
     /// Await a single reaction in this guild.
     #[cfg(feature = "collector")]
-    #[cfg_attr(docsrs, doc(cfg(feature = "collector")))]
     pub fn await_reaction<'a>(
         &self,
         shard_messenger: &'a impl AsRef<ShardMessenger>,
@@ -1137,7 +1132,6 @@ impl GuildId {
 
     /// Returns a stream builder which can be awaited to obtain a stream of reactions sent in this guild.
     #[cfg(feature = "collector")]
-    #[cfg_attr(docsrs, doc(cfg(feature = "collector")))]
     pub fn await_reactions<'a>(
         &self,
         shard_messenger: &'a impl AsRef<ShardMessenger>,
@@ -1156,7 +1150,6 @@ impl GuildId {
     /// [`ApplicationCommand`]: crate::model::interactions::application_command::ApplicationCommand
     /// [`create_global_application_command`]: crate::model::interactions::application_command::ApplicationCommand::create_global_application_command
     #[cfg(feature = "unstable_discord_api")]
-    #[cfg_attr(docsrs, doc(cfg(feature = "unstable_discord_api")))]
     pub async fn create_application_command<F>(
         &self,
         http: impl AsRef<Http>,
@@ -1170,8 +1163,13 @@ impl GuildId {
     }
 
     /// Overrides all guild application commands.
+    ///
+    /// # Errors
+    ///
+    /// Returns the same possible errors as [`set_global_application_commands`].
+    ///
+    /// [`set_global_application_commands`]: crate::model::interactions::application_command::ApplicationCommand::set_global_application_commands
     #[cfg(feature = "unstable_discord_api")]
-    #[cfg_attr(docsrs, doc(cfg(feature = "unstable_discord_api")))]
     pub async fn set_application_commands<F>(
         &self,
         http: impl AsRef<Http>,
@@ -1192,8 +1190,14 @@ impl GuildId {
     /// **Note**: It will update instantly.
     ///
     /// [`ApplicationCommandPermission`]: crate::model::interactions::application_command::ApplicationCommandPermission
+    ///
+    /// # Errors
+    ///
+    /// If there is an error, it will be either [`Error::Http`] or [`Error::Json`].
+    ///
+    /// [`Error::Http`]: crate::error::Error::Http
+    /// [`Error::Json`]: crate::error::Error::Json
     #[cfg(feature = "unstable_discord_api")]
-    #[cfg_attr(docsrs, doc(cfg(feature = "unstable_discord_api")))]
     pub async fn create_application_command_permission<F>(
         &self,
         http: impl AsRef<Http>,
@@ -1218,8 +1222,14 @@ impl GuildId {
     }
 
     /// Overrides all application commands permissions.
+    ///
+    /// # Errors
+    ///
+    /// If there is an error, it will be either [`Error::Http`] or [`Error::Json`].
+    ///
+    /// [`Error::Http`]: crate::error::Error::Http
+    /// [`Error::Json`]: crate::error::Error::Json
     #[cfg(feature = "unstable_discord_api")]
-    #[cfg_attr(docsrs, doc(cfg(feature = "unstable_discord_api")))]
     pub async fn set_application_commands_permissions<F>(
         &self,
         http: impl AsRef<Http>,
@@ -1239,8 +1249,14 @@ impl GuildId {
     }
 
     /// Get all guild application commands.
+    ///
+    /// # Errors
+    ///
+    /// If there is an error, it will be either [`Error::Http`] or [`Error::Json`].
+    ///
+    /// [`Error::Http`]: crate::error::Error::Http
+    /// [`Error::Json`]: crate::error::Error::Json
     #[cfg(feature = "unstable_discord_api")]
-    #[cfg_attr(docsrs, doc(cfg(feature = "unstable_discord_api")))]
     pub async fn get_application_commands(
         &self,
         http: impl AsRef<Http>,
@@ -1249,8 +1265,14 @@ impl GuildId {
     }
 
     /// Get a specific guild application command by its Id.
+    ///
+    /// # Errors
+    ///
+    /// If there is an error, it will be either [`Error::Http`] or [`Error::Json`].
+    ///
+    /// [`Error::Http`]: crate::error::Error::Http
+    /// [`Error::Json`]: crate::error::Error::Json
     #[cfg(feature = "unstable_discord_api")]
-    #[cfg_attr(docsrs, doc(cfg(feature = "unstable_discord_api")))]
     pub async fn get_application_command(
         &self,
         http: impl AsRef<Http>,
@@ -1260,8 +1282,14 @@ impl GuildId {
     }
 
     /// Edit guild application command by its Id.
+    ///
+    /// # Errors
+    ///
+    /// If there is an error, it will be either [`Error::Http`] or [`Error::Json`].
+    ///
+    /// [`Error::Http`]: crate::error::Error::Http
+    /// [`Error::Json`]: crate::error::Error::Json
     #[cfg(feature = "unstable_discord_api")]
-    #[cfg_attr(docsrs, doc(cfg(feature = "unstable_discord_api")))]
     pub async fn edit_application_command<F>(
         &self,
         http: impl AsRef<Http>,
@@ -1278,8 +1306,14 @@ impl GuildId {
     }
 
     /// Delete guild application command by its Id.
+    ///
+    /// # Errors
+    ///
+    /// If there is an error, it will be either [`Error::Http`] or [`Error::Json`].
+    ///
+    /// [`Error::Http`]: crate::error::Error::Http
+    /// [`Error::Json`]: crate::error::Error::Json
     #[cfg(feature = "unstable_discord_api")]
-    #[cfg_attr(docsrs, doc(cfg(feature = "unstable_discord_api")))]
     pub async fn delete_application_command(
         &self,
         http: impl AsRef<Http>,
@@ -1289,8 +1323,14 @@ impl GuildId {
     }
 
     /// Get all guild application commands permissions only.
+    ///
+    /// # Errors
+    ///
+    /// If there is an error, it will be either [`Error::Http`] or [`Error::Json`].
+    ///
+    /// [`Error::Http`]: crate::error::Error::Http
+    /// [`Error::Json`]: crate::error::Error::Json
     #[cfg(feature = "unstable_discord_api")]
-    #[cfg_attr(docsrs, doc(cfg(feature = "unstable_discord_api")))]
     pub async fn get_application_commands_permissions(
         &self,
         http: impl AsRef<Http>,
@@ -1299,8 +1339,14 @@ impl GuildId {
     }
 
     /// Get permissions for specific guild application command by its Id.
+    ///
+    /// # Errors
+    ///
+    /// If there is an error, it will be either [`Error::Http`] or [`Error::Json`].
+    ///
+    /// [`Error::Http`]: crate::error::Error::Http
+    /// [`Error::Json`]: crate::error::Error::Json
     #[cfg(feature = "unstable_discord_api")]
-    #[cfg_attr(docsrs, doc(cfg(feature = "unstable_discord_api")))]
     pub async fn get_application_command_permissions(
         &self,
         http: impl AsRef<Http>,
@@ -1343,6 +1389,16 @@ impl GuildId {
     pub fn widget_image_url(&self, style: GuildWidgetStyle) -> String {
         format!(api!("/guilds/{}/widget.png?style={}"), self.0.to_string(), style.to_string())
     }
+
+    /// Gets the guild active threads.
+    ///
+    /// # Errors
+    ///
+    /// Returns [`Error::Http`] if there is an error in the deserialization, or
+    /// if the bot issuing the request is not in the guild.
+    pub async fn get_active_threads(&self, http: impl AsRef<Http>) -> Result<ThreadsData> {
+        http.as_ref().get_guild_active_threads(self.0).await
+    }
 }
 
 impl From<PartialGuild> for GuildId {
@@ -1464,17 +1520,13 @@ impl<H: AsRef<Http>> MembersIter<H> {
     /// # async fn run() {
     /// # let guild_id = GuildId::default();
     /// # let ctx = Http::default();
-    /// use serenity::model::guild::MembersIter;
     /// use serenity::futures::StreamExt;
+    /// use serenity::model::guild::MembersIter;
     ///
     /// let mut members = MembersIter::<Http>::stream(&ctx, guild_id).boxed();
     /// while let Some(member_result) = members.next().await {
     ///     match member_result {
-    ///         Ok(member) => println!(
-    ///             "{} is {}",
-    ///             member,
-    ///             member.display_name(),
-    ///         ),
+    ///         Ok(member) => println!("{} is {}", member, member.display_name(),),
     ///         Err(error) => eprintln!("Uh oh!  Error: {}", error),
     ///     }
     /// }
@@ -1508,11 +1560,11 @@ pub enum GuildWidgetStyle {
 impl Display for GuildWidgetStyle {
     fn fmt(&self, f: &mut Formatter<'_>) -> core::fmt::Result {
         match self {
-            GuildWidgetStyle::Shield => write!(f, "shield"),
-            GuildWidgetStyle::Banner1 => write!(f, "banner1"),
-            GuildWidgetStyle::Banner2 => write!(f, "banner2"),
-            GuildWidgetStyle::Banner3 => write!(f, "banner3"),
-            GuildWidgetStyle::Banner4 => write!(f, "banner4"),
+            GuildWidgetStyle::Shield => f.write_str("shield"),
+            GuildWidgetStyle::Banner1 => f.write_str("banner1"),
+            GuildWidgetStyle::Banner2 => f.write_str("banner2"),
+            GuildWidgetStyle::Banner3 => f.write_str("banner3"),
+            GuildWidgetStyle::Banner4 => f.write_str("banner4"),
         }
     }
 }
