@@ -1,9 +1,9 @@
 #[cfg(feature = "model")]
 use std::borrow::Cow;
+#[cfg(all(feature = "cache", feature = "model"))]
 use std::cmp::Reverse;
 use std::fmt::{Display, Formatter, Result as FmtResult};
 
-#[cfg(feature = "model")]
 use bitflags::__impl_bitflags;
 use chrono::{DateTime, Utc};
 use serde::{Serialize, Serializer};
@@ -55,10 +55,13 @@ pub struct Member {
     ///
     /// [`Interaction`]: crate::model::interactions::Interaction
     #[cfg(feature = "unstable_discord_api")]
-    #[cfg_attr(docsrs, doc(cfg(feature = "unstable_discord_api")))]
     pub permissions: Option<Permissions>,
     /// The guild avatar hash
     pub avatar: Option<String>,
+    /// 	When the user's timeout will expire and the user will be able to communicate in the guild again.
+    ///
+    /// 	Will be None or a time in the past if the user is not timed out.
+    pub communication_disabled_until: Option<DateTime<Utc>>,
 }
 
 #[cfg(feature = "model")]
@@ -199,6 +202,40 @@ impl Member {
         None
     }
 
+    /// Times the user out until `time`.
+    ///
+    /// Requires the [Moderate Members] permission.
+    ///
+    /// **Note**: [Moderate Members]: crate::model::permission::Permissions::MODERATE_MEMBERS
+    ///
+    /// # Errors
+    ///
+    /// Returns [`Error::Http`] if the current user lacks permission or if `time` is greater than
+    /// 28 days from the current time.
+    ///
+    /// [Moderate Members]: Permissions::MODERATE_MEMBERS
+    #[doc(alias = "timeout")]
+    pub async fn disable_communication_until_datetime(
+        &mut self,
+        http: impl AsRef<Http>,
+        time: DateTime<Utc>,
+    ) -> Result<()> {
+        match self
+            .guild_id
+            .edit_member(http, self.user.id, |member| {
+                member.disable_communication_until_datetime(time);
+                member
+            })
+            .await
+        {
+            Ok(_) => {
+                self.communication_disabled_until = Some(time);
+                Ok(())
+            },
+            Err(why) => Err(why),
+        }
+    }
+
     /// Calculates the member's display name.
     ///
     /// The nickname takes priority over the member's username if it exists.
@@ -235,6 +272,33 @@ impl Member {
         http.as_ref().edit_member(self.guild_id.0, self.user.id.0, &map).await
     }
 
+    /// Allow a user to communicate, removing their timeout, if there is one.
+    ///
+    /// **Note**: Requires the [Moderate Members] permission.
+    ///
+    /// # Errors
+    ///
+    /// Returns [`Error::Http`] if the current user lacks permission.
+    ///
+    /// [Moderate Members]: Permissions::MODERATE_MEMBERS
+    #[doc(alias = "timeout")]
+    pub async fn enable_communication(&mut self, http: impl AsRef<Http>) -> Result<()> {
+        match self
+            .guild_id
+            .edit_member(&http, self.user.id, |member| {
+                member.enable_communication();
+                member
+            })
+            .await
+        {
+            Ok(_) => {
+                self.communication_disabled_until = None;
+                Ok(())
+            },
+            Err(why) => Err(why),
+        }
+    }
+
     /// Retrieves the ID and position of the member's highest role in the
     /// hierarchy, if they have one.
     ///
@@ -589,7 +653,6 @@ pub struct PartialMember {
     ///
     /// [`Interaction`]: crate::model::interactions::Interaction
     #[cfg(feature = "unstable_discord_api")]
-    #[cfg_attr(docsrs, doc(cfg(feature = "unstable_discord_api")))]
     pub permissions: Option<Permissions>,
 }
 
@@ -624,7 +687,7 @@ pub struct ThreadMemberFlags {
 __impl_bitflags! {
     ThreadMemberFlags: u64 {
         // Not documented.
-        NOTIFICATIONS = 0b0000_0000_0000_0000_0000_0000_0000_0001;
+        NOTIFICATIONS = 1 << 0;
     }
 }
 
