@@ -13,7 +13,7 @@ use crate::builder::{
 };
 use crate::http::Http;
 use crate::internal::prelude::{JsonMap, StdResult, Value};
-use crate::model::channel::PartialChannel;
+use crate::model::channel::{ChannelType, PartialChannel};
 use crate::model::guild::{Member, PartialMember, Role};
 use crate::model::id::{
     ApplicationId,
@@ -28,6 +28,7 @@ use crate::model::interactions::InteractionType;
 use crate::model::prelude::User;
 use crate::model::utils::{
     deserialize_channels_map,
+    deserialize_messages_map,
     deserialize_options,
     deserialize_options_with_resolved,
     deserialize_partial_members_map,
@@ -65,6 +66,10 @@ pub struct ApplicationCommandInteraction {
     pub token: String,
     /// Always `1`.
     pub version: u8,
+    /// The guild's preferred locale.
+    pub guild_locale: Option<String>,
+    /// The selected language of the invoking user.
+    pub locale: String,
 }
 
 impl ApplicationCommandInteraction {
@@ -90,8 +95,6 @@ impl ApplicationCommandInteraction {
     /// or an [`Error::Json`] if there is an error in deserializing the
     /// API response.
     ///
-    /// # Errors
-    ///
     /// [`Error::Model`]: crate::error::Error::Model
     /// [`Error::Http`]: crate::error::Error::Http
     /// [`Error::Json`]: crate::error::Error::Json
@@ -242,6 +245,39 @@ impl ApplicationCommandInteraction {
     ) -> Result<()> {
         http.as_ref().delete_followup_message(&self.token, message_id.into().into()).await
     }
+
+    /// Gets a followup message.
+    ///
+    /// # Errors
+    ///
+    /// May return [`Error::Http`] if the API returns an error.
+    /// Such as if the response was deleted.
+    pub async fn get_followup_message<M: Into<MessageId>>(
+        &self,
+        http: impl AsRef<Http>,
+        message_id: M,
+    ) -> Result<Message> {
+        http.as_ref().get_followup_message(&self.token, message_id.into().into()).await
+    }
+
+    /// Helper function to defer an interaction
+    ///
+    /// # Errors
+    ///
+    /// May also return an [`Error::Http`] if the API returns an error,
+    /// or an [`Error::Json`] if there is an error in deserializing the
+    /// API response.
+    ///
+    /// # Errors
+    ///
+    /// [`Error::Http`]: crate::error::Error::Http
+    /// [`Error::Json`]: crate::error::Error::Json
+    pub async fn defer(&self, http: impl AsRef<Http>) -> Result<()> {
+        self.create_interaction_response(http, |f| {
+            f.kind(InteractionResponseType::DeferredChannelMessageWithSource)
+        })
+        .await
+    }
 }
 
 impl<'de> Deserialize<'de> for ApplicationCommandInteraction {
@@ -260,7 +296,7 @@ impl<'de> Deserialize<'de> for ApplicationCommandInteraction {
                     if let Some(roles) = resolved.get_mut("roles") {
                         if let Some(values) = roles.as_object_mut() {
                             for value in values.values_mut() {
-                                value.as_object_mut().unwrap().insert(
+                                value.as_object_mut().expect("couldn't deserialize").insert(
                                     "guild_id".to_string(),
                                     Value::String(guild_id.to_string()),
                                 );
@@ -271,10 +307,13 @@ impl<'de> Deserialize<'de> for ApplicationCommandInteraction {
                     if let Some(channels) = resolved.get_mut("channels") {
                         if let Some(values) = channels.as_object_mut() {
                             for value in values.values_mut() {
-                                value.as_object_mut().unwrap().insert(
-                                    "guild_id".to_string(),
-                                    Value::String(guild_id.to_string()),
-                                );
+                                value
+                                    .as_object_mut()
+                                    .expect("couldn't deserialize application command")
+                                    .insert(
+                                        "guild_id".to_string(),
+                                        Value::String(guild_id.to_string()),
+                                    );
                             }
                         }
                     }
@@ -353,6 +392,22 @@ impl<'de> Deserialize<'de> for ApplicationCommandInteraction {
             .and_then(u8::deserialize)
             .map_err(DeError::custom)?;
 
+        let guild_locale = match map.contains_key("guild_locale") {
+            true => Some(
+                map.remove("guild_locale")
+                    .ok_or_else(|| DeError::custom("expected guild_locale"))
+                    .and_then(String::deserialize)
+                    .map_err(DeError::custom)?,
+            ),
+            false => None,
+        };
+
+        let locale = map
+            .remove("locale")
+            .ok_or_else(|| DeError::custom("expected locale"))
+            .and_then(String::deserialize)
+            .map_err(DeError::custom)?;
+
         Ok(Self {
             id,
             application_id,
@@ -364,6 +419,8 @@ impl<'de> Deserialize<'de> for ApplicationCommandInteraction {
             user,
             token,
             version,
+            guild_locale,
+            locale,
         })
     }
 }
@@ -376,12 +433,29 @@ pub struct ApplicationCommandInteractionData {
     pub id: CommandId,
     /// The name of the invoked command.
     pub name: String,
+    /// The application command type of the triggered application command.
+    #[serde(rename = "type")]
+    pub kind: ApplicationCommandType,
     /// The parameters and the given values.
     #[serde(default)]
     pub options: Vec<ApplicationCommandInteractionDataOption>,
     /// The converted objects from the given options.
     #[serde(default)]
     pub resolved: ApplicationCommandInteractionDataResolved,
+    /// The targeted user or message, if the triggered application command type
+    /// is [`User`] or [`Message`].
+    ///
+    /// Its object data can be found in the [`resolved`] field.
+    ///
+    /// [`resolved`]: Self::resolved
+    /// [`User`]: ApplicationCommandType::User
+    /// [`Message`]: ApplicationCommandType::Message
+    pub target_id: Option<TargetId>,
+    /// The target resolved data of [`target_id`]
+    ///
+    /// [`target_id`]: Self::target_id
+    #[serde(skip_serializing)]
+    pub target: Option<ResolvedTarget>,
 }
 
 impl<'de> Deserialize<'de> for ApplicationCommandInteractionData {
@@ -418,15 +492,65 @@ impl<'de> Deserialize<'de> for ApplicationCommandInteractionData {
             false => vec![],
         };
 
+        let kind = map
+            .remove("type")
+            .ok_or_else(|| DeError::custom("expected type"))
+            .and_then(ApplicationCommandType::deserialize)
+            .map_err(DeError::custom)?;
+
+        let target_id = match kind != ApplicationCommandType::ChatInput {
+            true => Some(
+                map.remove("target_id")
+                    .ok_or_else(|| DeError::custom("expected resolved"))
+                    .and_then(TargetId::deserialize)
+                    .map_err(DeError::custom)?,
+            ),
+            false => None,
+        };
+
+        let target = match target_id {
+            Some(id) => {
+                if kind == ApplicationCommandType::Message {
+                    let resolved = resolved
+                        .messages
+                        .get(&id.to_message_id())
+                        .expect("expected message object")
+                        .to_owned();
+
+                    Some(ResolvedTarget::Message(resolved))
+                } else {
+                    let user_id = id.to_user_id();
+
+                    let user = resolved.users.get(&user_id).expect("expected user").to_owned();
+                    let member = resolved.members.get(&user_id).map(|m| m.to_owned());
+
+                    Some(ResolvedTarget::User(user, member))
+                }
+            },
+            None => None,
+        };
+
         Ok(Self {
             name,
             id,
+            kind,
             options,
             resolved,
+            target_id,
+            target,
         })
     }
 }
 
+/// The resolved value of a [`ApplicationCommandInteractionData::target_id`].
+#[derive(Clone, Debug, Serialize, Deserialize)]
+#[non_exhaustive]
+#[repr(u8)]
+pub enum ResolvedTarget {
+    User(User, Option<PartialMember>),
+    Message(Message),
+}
+
 /// The resolved data of a command data interaction payload.
 /// It contains the objects of [`ApplicationCommandInteractionDataOption`]s.
 #[derive(Clone, Debug, Serialize, Default)]
@@ -440,6 +564,8 @@ pub struct ApplicationCommandInteractionDataResolved {
     pub roles: HashMap<RoleId, Role>,
     /// The resolved partial channels.
     pub channels: HashMap<ChannelId, PartialChannel>,
+    /// The resolved messages.
+    pub messages: HashMap<MessageId, Message>,
 }
 
 impl<'de> Deserialize<'de> for ApplicationCommandInteractionDataResolved {
@@ -476,17 +602,27 @@ impl<'de> Deserialize<'de> for ApplicationCommandInteractionDataResolved {
         let channels = match map.contains_key("channels") {
             true => map
                 .remove("channels")
-                .ok_or_else(|| DeError::custom("expected chanels"))
+                .ok_or_else(|| DeError::custom("expected channels"))
                 .and_then(deserialize_channels_map)
                 .map_err(DeError::custom)?,
             false => HashMap::new(),
         };
 
+        let messages = match map.contains_key("messages") {
+            true => map
+                .remove("messages")
+                .ok_or_else(|| DeError::custom("expected messages"))
+                .and_then(deserialize_messages_map)
+                .map_err(DeError::custom)?,
+            false => HashMap::new(),
+        };
+
         Ok(Self {
             users,
             members,
             roles,
             channels,
+            messages,
         })
     }
 }
@@ -516,6 +652,10 @@ pub struct ApplicationCommandInteractionDataOption {
     /// The resolved object of the given `value`, if there is one.
     #[serde(default)]
     pub resolved: Option<ApplicationCommandInteractionDataOptionValue>,
+    /// For `Autocomplete` Interactions this will be `true` if
+    /// this option is currently focused by the user.
+    #[serde(default)]
+    pub focused: bool,
 }
 
 impl<'de> Deserialize<'de> for ApplicationCommandInteractionDataOption {
@@ -553,12 +693,18 @@ impl<'de> Deserialize<'de> for ApplicationCommandInteractionDataOption {
             false => vec![],
         };
 
+        let focused = match map.get("focused") {
+            Some(value) => value.as_bool().ok_or_else(|| DeError::custom("expected bool"))?,
+            None => false,
+        };
+
         Ok(Self {
             name,
             value,
             kind,
             options,
             resolved: None,
+            focused,
         })
     }
 }
@@ -587,6 +733,9 @@ fn default_permission_value() -> bool {
 pub struct ApplicationCommand {
     /// The command Id.
     pub id: CommandId,
+    /// The application command kind.
+    #[serde(rename = "type")]
+    pub kind: ApplicationCommandType,
     /// The parent application Id.
     pub application_id: ApplicationId,
     /// The command guild Id, if it is a guild command.
@@ -604,6 +753,8 @@ pub struct ApplicationCommand {
     /// the application is added to a guild.
     #[serde(default = "self::default_permission_value")]
     pub default_permission: bool,
+    /// An autoincremented version identifier updated during substantial record changes.
+    pub version: CommandVersionId,
 }
 
 impl ApplicationCommand {
@@ -628,11 +779,13 @@ impl ApplicationCommand {
     /// #
     /// # async fn run() {
     /// # let http = Arc::new(Http::default());
-    /// use serenity::model::{interactions::application_command::ApplicationCommand, id::ApplicationId};
+    /// use serenity::model::{
+    ///     id::ApplicationId,
+    ///     interactions::application_command::ApplicationCommand,
+    /// };
     ///
     /// let _ = ApplicationCommand::create_global_application_command(&http, |command| {
-    ///    command.name("ping")
-    ///     .description("A simple ping command")
+    ///     command.name("ping").description("A simple ping command")
     /// })
     /// .await;
     /// # }
@@ -647,18 +800,17 @@ impl ApplicationCommand {
     /// # async fn run() {
     /// # let http = Arc::new(Http::default());
     /// use serenity::model::{
+    ///     id::ApplicationId,
     ///     interactions::application_command::{ApplicationCommand, ApplicationCommandOptionType},
-    ///     id::ApplicationId
     /// };
     ///
     /// let _ = ApplicationCommand::create_global_application_command(&http, |command| {
-    ///    command.name("echo")
-    ///     .description("Makes the bot send a message")
-    ///     .create_option(|option| {
-    ///         option.name("message")
-    ///          .description("The message to send")
-    ///          .kind(ApplicationCommandOptionType::String)
-    ///          .required(true)
+    ///     command.name("echo").description("Makes the bot send a message").create_option(|option| {
+    ///         option
+    ///             .name("message")
+    ///             .description("The message to send")
+    ///             .kind(ApplicationCommandOptionType::String)
+    ///             .required(true)
     ///     })
     /// })
     /// .await;
@@ -693,6 +845,13 @@ impl ApplicationCommand {
     /// Overrides all global application commands.
     ///
     /// [`create_global_application_command`]: Self::create_global_application_command
+    ///
+    /// # Errors
+    ///
+    /// If there is an error, it will be either [`Error::Http`] or [`Error::Json`].
+    ///
+    /// [`Error::Http`]: crate::error::Error::Http
+    /// [`Error::Json`]: crate::error::Error::Json
     pub async fn set_global_application_commands<F>(
         http: impl AsRef<Http>,
         f: F,
@@ -708,6 +867,13 @@ impl ApplicationCommand {
     }
 
     /// Edits a global command by its Id.
+    ///
+    /// # Errors
+    ///
+    /// If there is an error, it will be either [`Error::Http`] or [`Error::Json`].
+    ///
+    /// [`Error::Http`]: crate::error::Error::Http
+    /// [`Error::Json`]: crate::error::Error::Json
     pub async fn edit_global_application_command<F>(
         http: impl AsRef<Http>,
         command_id: CommandId,
@@ -721,6 +887,13 @@ impl ApplicationCommand {
     }
 
     /// Gets all global commands.
+    ///
+    /// # Errors
+    ///
+    /// If there is an error, it will be either [`Error::Http`] or [`Error::Json`].
+    ///
+    /// [`Error::Http`]: crate::error::Error::Http
+    /// [`Error::Json`]: crate::error::Error::Json
     pub async fn get_global_application_commands(
         http: impl AsRef<Http>,
     ) -> Result<Vec<ApplicationCommand>> {
@@ -728,6 +901,13 @@ impl ApplicationCommand {
     }
 
     /// Gets a global command by its Id.
+    ///
+    /// # Errors
+    ///
+    /// If there is an error, it will be either [`Error::Http`] or [`Error::Json`].
+    ///
+    /// [`Error::Http`]: crate::error::Error::Http
+    /// [`Error::Json`]: crate::error::Error::Json
     pub async fn get_global_application_command(
         http: impl AsRef<Http>,
         command_id: CommandId,
@@ -736,6 +916,13 @@ impl ApplicationCommand {
     }
 
     /// Deletes a global command by its Id.
+    ///
+    /// # Errors
+    ///
+    /// If there is an error, it will be either [`Error::Http`] or [`Error::Json`].
+    ///
+    /// [`Error::Http`]: crate::error::Error::Http
+    /// [`Error::Json`]: crate::error::Error::Json
     pub async fn delete_global_application_command(
         http: impl AsRef<Http>,
         command_id: CommandId,
@@ -754,6 +941,23 @@ impl ApplicationCommand {
     }
 }
 
+/// The type of an application command.
+#[derive(Copy, Clone, Debug, Hash, Eq, PartialEq, PartialOrd, Ord)]
+#[non_exhaustive]
+#[repr(u8)]
+pub enum ApplicationCommandType {
+    ChatInput = 1,
+    User = 2,
+    Message = 3,
+    Unknown = !0,
+}
+
+enum_number!(ApplicationCommandType {
+    ChatInput,
+    User,
+    Message
+});
+
 /// The parameters for an [`ApplicationCommand`].
 #[derive(Clone, Debug, Deserialize, Serialize)]
 #[non_exhaustive]
@@ -784,6 +988,17 @@ pub struct ApplicationCommandOption {
     /// [`SubCommandGroup`]: ApplicationCommandOptionType::SubCommandGroup
     #[serde(default)]
     pub options: Vec<ApplicationCommandOption>,
+    /// If the option is a [`Channel`], it will only be able to show these types.
+    ///
+    /// [`Channel`]: ApplicationCommandOptionType::Channel
+    #[serde(default)]
+    pub channel_types: Vec<ChannelType>,
+    /// Minimum permitted value for Integer or Number options
+    #[serde(default)]
+    pub min_value: Option<serde_json::Number>,
+    /// Maximum permitted value for Integer or Number options
+    #[serde(default)]
+    pub max_value: Option<serde_json::Number>,
 }
 
 /// An [`ApplicationCommand`] permission.
@@ -819,12 +1034,12 @@ pub struct ApplicationCommandPermissionData {
 impl CommandPermissionId {
     /// Converts this [`CommandPermissionId`] to [`UserId`].
     pub fn to_user_id(self) -> UserId {
-        UserId(self.0)
+        self.0.into()
     }
 
     /// Converts this [`CommandPermissionId`] to [`RoleId`].
     pub fn to_role_id(self) -> RoleId {
-        RoleId(self.0)
+        self.0.into()
     }
 }
 
@@ -864,6 +1079,54 @@ impl From<CommandPermissionId> for UserId {
     }
 }
 
+impl TargetId {
+    /// Converts this [`CommandPermissionId`] to [`UserId`].
+    pub fn to_user_id(self) -> UserId {
+        self.0.into()
+    }
+
+    /// Converts this [`CommandPermissionId`] to [`MessageId`].
+    pub fn to_message_id(self) -> MessageId {
+        self.0.into()
+    }
+}
+
+impl From<MessageId> for TargetId {
+    fn from(id: MessageId) -> Self {
+        Self(id.0)
+    }
+}
+
+impl<'a> From<&'a MessageId> for TargetId {
+    fn from(id: &MessageId) -> Self {
+        Self(id.0)
+    }
+}
+
+impl From<UserId> for TargetId {
+    fn from(id: UserId) -> Self {
+        Self(id.0)
+    }
+}
+
+impl<'a> From<&'a UserId> for TargetId {
+    fn from(id: &UserId) -> Self {
+        Self(id.0)
+    }
+}
+
+impl From<TargetId> for MessageId {
+    fn from(id: TargetId) -> Self {
+        Self(id.0)
+    }
+}
+
+impl From<TargetId> for UserId {
+    fn from(id: TargetId) -> Self {
+        Self(id.0)
+    }
+}
+
 /// The type of an [`ApplicationCommandOption`].
 #[derive(Copy, Clone, Debug, Hash, Eq, PartialEq, PartialOrd, Ord)]
 #[non_exhaustive]
