@@ -28,7 +28,7 @@ pub struct MessageComponentInteraction {
     pub data: MessageComponentInteractionData,
     /// The message this interaction was triggered by, if
     /// it is a component.
-    pub message: InteractionMessage,
+    pub message: Message,
     /// The guild Id this interaction was sent from, if there is one.
     #[serde(skip_serializing_if = "Option::is_none")]
     pub guild_id: Option<GuildId>,
@@ -45,6 +45,10 @@ pub struct MessageComponentInteraction {
     pub token: String,
     /// Always `1`.
     pub version: u8,
+    /// The guild's preferred locale.
+    pub guild_locale: Option<String>,
+    /// The selected language of the invoking user.
+    pub locale: String,
 }
 
 impl MessageComponentInteraction {
@@ -222,6 +226,39 @@ impl MessageComponentInteraction {
     ) -> Result<()> {
         http.as_ref().delete_followup_message(&self.token, message_id.into().into()).await
     }
+
+    /// Gets a followup message.
+    ///
+    /// # Errors
+    ///
+    /// May return [`Error::Http`] if the API returns an error.
+    /// Such as if the response was deleted.
+    pub async fn get_followup_message<M: Into<MessageId>>(
+        &self,
+        http: impl AsRef<Http>,
+        message_id: M,
+    ) -> Result<Message> {
+        http.as_ref().get_followup_message(&self.token, message_id.into().into()).await
+    }
+
+    /// Helper function to defer an interaction
+    ///
+    /// # Errors
+    ///
+    /// May also return an [`Error::Http`] if the API returns an error,
+    /// or an [`Error::Json`] if there is an error in deserializing the
+    /// API response.
+    ///
+    /// # Errors
+    ///
+    /// [`Error::Http`]: crate::error::Error::Http
+    /// [`Error::Json`]: crate::error::Error::Json
+    pub async fn defer(&self, http: impl AsRef<Http>) -> Result<()> {
+        self.create_interaction_response(http, |f| {
+            f.kind(InteractionResponseType::DeferredUpdateMessage)
+        })
+        .await
+    }
 }
 
 impl<'de> Deserialize<'de> for MessageComponentInteraction {
@@ -240,10 +277,13 @@ impl<'de> Deserialize<'de> for MessageComponentInteraction {
                     if let Some(roles) = resolved.get_mut("roles") {
                         if let Some(values) = roles.as_object_mut() {
                             for value in values.values_mut() {
-                                value.as_object_mut().unwrap().insert(
-                                    "guild_id".to_string(),
-                                    Value::String(guild_id.to_string()),
-                                );
+                                value
+                                    .as_object_mut()
+                                    .expect("couldn't deserialize message component")
+                                    .insert(
+                                        "guild_id".to_string(),
+                                        Value::String(guild_id.to_string()),
+                                    );
                             }
                         }
                     }
@@ -251,10 +291,15 @@ impl<'de> Deserialize<'de> for MessageComponentInteraction {
                     if let Some(channels) = resolved.get_mut("channels") {
                         if let Some(values) = channels.as_object_mut() {
                             for value in values.values_mut() {
-                                value.as_object_mut().unwrap().insert(
-                                    "guild_id".to_string(),
-                                    Value::String(guild_id.to_string()),
-                                );
+                                value
+                                    .as_object_mut()
+                                    .expect(
+                                        "couldn't deserialize the message component interaction",
+                                    )
+                                    .insert(
+                                        "guild_id".to_string(),
+                                        Value::String(guild_id.to_string()),
+                                    );
                             }
                         }
                     }
@@ -321,25 +366,11 @@ impl<'de> Deserialize<'de> for MessageComponentInteraction {
             false => member.as_ref().expect("expected user or member").user.clone(),
         };
 
-        let message = {
-            let message = map
-                .remove("message")
-                .ok_or_else(|| DeError::custom("expected message"))
-                .and_then(JsonMap::deserialize)
-                .map_err(DeError::custom)?;
-
-            let partial = !message.contains_key("author");
-
-            let value: Value = message.into();
-
-            if partial {
-                InteractionMessage::Ephemeral(
-                    EphemeralMessage::deserialize(value).map_err(DeError::custom)?,
-                )
-            } else {
-                InteractionMessage::Regular(Message::deserialize(value).map_err(DeError::custom)?)
-            }
-        };
+        let message = map
+            .remove("message")
+            .ok_or_else(|| DeError::custom("expected message"))
+            .and_then(Message::deserialize)
+            .map_err(DeError::custom)?;
 
         let token = map
             .remove("token")
@@ -353,6 +384,22 @@ impl<'de> Deserialize<'de> for MessageComponentInteraction {
             .and_then(u8::deserialize)
             .map_err(DeError::custom)?;
 
+        let guild_locale = match map.contains_key("guild_locale") {
+            true => Some(
+                map.remove("guild_locale")
+                    .ok_or_else(|| DeError::custom("expected guild_locale"))
+                    .and_then(String::deserialize)
+                    .map_err(DeError::custom)?,
+            ),
+            false => None,
+        };
+
+        let locale = map
+            .remove("locale")
+            .ok_or_else(|| DeError::custom("expected locale"))
+            .and_then(String::deserialize)
+            .map_err(DeError::custom)?;
+
         Ok(Self {
             id,
             application_id,
@@ -365,6 +412,8 @@ impl<'de> Deserialize<'de> for MessageComponentInteraction {
             user,
             token,
             version,
+            guild_locale,
+            locale,
         })
     }
 }
@@ -626,64 +675,3 @@ pub struct SelectMenuOption {
     #[serde(default)]
     pub default: bool,
 }
-
-/// The [`MessageComponentInteraction::message`] field.
-#[derive(Clone, Debug, Deserialize)]
-pub enum InteractionMessage {
-    Regular(Message),
-    Ephemeral(EphemeralMessage),
-}
-
-impl InteractionMessage {
-    /// Whether the message is ephemeral.
-    pub fn is_ephemeral(&self) -> bool {
-        matches!(self, InteractionMessage::Ephemeral(_))
-    }
-
-    /// Gets the message Id.
-    pub fn id(&self) -> MessageId {
-        match self {
-            InteractionMessage::Regular(m) => m.id,
-            InteractionMessage::Ephemeral(m) => m.id,
-        }
-    }
-
-    /// Converts this to a regular message,
-    /// if it is one.
-    pub fn regular(self) -> Option<Message> {
-        match self {
-            InteractionMessage::Regular(m) => Some(m),
-            InteractionMessage::Ephemeral(_) => None,
-        }
-    }
-
-    /// Converts this to an ephemeral message,
-    /// if it is one.
-    pub fn ephemeral(self) -> Option<EphemeralMessage> {
-        match self {
-            InteractionMessage::Regular(_) => None,
-            InteractionMessage::Ephemeral(m) => Some(m),
-        }
-    }
-}
-
-impl Serialize for InteractionMessage {
-    fn serialize<S>(&self, serializer: S) -> StdResult<S::Ok, S::Error>
-    where
-        S: Serializer,
-    {
-        match self {
-            InteractionMessage::Regular(c) => Message::serialize(c, serializer),
-            InteractionMessage::Ephemeral(c) => EphemeralMessage::serialize(c, serializer),
-        }
-    }
-}
-
-/// An ephemeral message given in an interaction.
-#[derive(Clone, Debug, Deserialize, Serialize)]
-pub struct EphemeralMessage {
-    /// The message flags.
-    pub flags: MessageFlags,
-    /// The message Id.
-    pub id: MessageId,
-}
