@@ -5,6 +5,7 @@ use std::fmt;
 use std::fmt::Write;
 
 use bitflags::__impl_bitflags;
+#[cfg(feature = "model")]
 use futures::future::{BoxFuture, FutureExt};
 use serde::{Deserialize, Deserializer, Serialize, Serializer};
 #[cfg(feature = "model")]
@@ -49,6 +50,11 @@ pub struct CurrentUser {
     pub name: String,
     pub verified: Option<bool>,
     pub public_flags: Option<UserPublicFlags>,
+    pub banner: Option<String>,
+    #[cfg(feature = "utils")]
+    pub accent_colour: Option<Colour>,
+    #[cfg(not(feature = "utils"))]
+    pub accent_colour: Option<u32>,
 }
 
 #[cfg(feature = "model")]
@@ -74,7 +80,7 @@ impl CurrentUser {
     ///
     /// match user.avatar_url() {
     ///     Some(url) => println!("{}'s avatar can be found at {}", user.name, url),
-    ///     None => println!("{} does not have an avatar set.", user.name)
+    ///     None => println!("{} does not have an avatar set.", user.name),
     /// }
     /// # }
     /// ```
@@ -237,8 +243,11 @@ impl CurrentUser {
     ///     },
     /// };
     ///
-    /// assert_eq!(url, "https://discordapp.com/api/oauth2/authorize? \
-    ///                  client_id=249608697955745802&scope=bot");
+    /// assert_eq!(
+    ///     url,
+    ///     "https://discordapp.com/api/oauth2/authorize? \
+    ///                  client_id=249608697955745802&scope=bot"
+    /// );
     /// # }
     /// ```
     ///
@@ -254,7 +263,8 @@ impl CurrentUser {
     /// use serenity::model::Permissions;
     ///
     /// // assuming the user has been bound
-    /// let permissions = Permissions::READ_MESSAGES | Permissions::SEND_MESSAGES | Permissions::EMBED_LINKS;
+    /// let permissions =
+    ///     Permissions::READ_MESSAGES | Permissions::SEND_MESSAGES | Permissions::EMBED_LINKS;
     /// let url = match user.invite_url(&http, permissions).await {
     ///     Ok(v) => v,
     ///     Err(why) => {
@@ -264,9 +274,11 @@ impl CurrentUser {
     ///     },
     /// };
     ///
-    /// assert_eq!(url,
-    /// "https://discordapp.
-    /// com/api/oauth2/authorize?client_id=249608697955745802&scope=bot&permissions=19456");
+    /// assert_eq!(
+    ///     url,
+    ///     "https://discordapp.
+    /// com/api/oauth2/authorize?client_id=249608697955745802&scope=bot&permissions=19456"
+    /// );
     /// # }
     /// ```
     ///
@@ -300,8 +312,8 @@ impl CurrentUser {
     /// # async fn run() {
     /// #     let user = CurrentUser::default();
     /// #     let http = Http::default();
-    /// use serenity::model::Permissions;
     /// use serenity::model::oauth2::OAuth2Scope;
+    /// use serenity::model::Permissions;
     ///
     /// let scopes = vec![OAuth2Scope::Bot, OAuth2Scope::ApplicationsCommands];
     ///
@@ -315,8 +327,11 @@ impl CurrentUser {
     ///     },
     /// };
     ///
-    /// assert_eq!(url, "https://discordapp.com/api/oauth2/authorize? \
-    ///                  client_id=249608697955745802&scope=bot%20applications.commands");
+    /// assert_eq!(
+    ///     url,
+    ///     "https://discordapp.com/api/oauth2/authorize? \
+    ///                  client_id=249608697955745802&scope=bot%20applications.commands"
+    /// );
     /// # }
     /// ```
     /// # Errors
@@ -360,7 +375,7 @@ impl CurrentUser {
     ///
     /// match user.static_avatar_url() {
     ///     Some(url) => println!("{}'s static avatar can be found at {}", user.name, url),
-    ///     None => println!("Could not get static avatar for {}.", user.name)
+    ///     None => println!("Could not get static avatar for {}.", user.name),
     /// }
     /// # }
     /// ```
@@ -491,8 +506,24 @@ pub struct User {
     /// change if the username+discriminator pair becomes non-unique.
     #[serde(rename = "username")]
     pub name: String,
-    /// the public flags on a user's account
+    /// The public flags on a user's account
     pub public_flags: Option<UserPublicFlags>,
+    /// Optional banner hash.
+    ///
+    /// **Note**: This will only be present if the user is fetched via Rest API,
+    /// e.g. with [`Http::get_user`].
+    pub banner: Option<String>,
+    /// The user's banner colour encoded as an integer representation of
+    /// hexadecimal colour code
+    ///
+    /// **Note**: This will only be present if the user is fetched via Rest API,
+    /// e.g. with [`Http::get_user`].
+    #[cfg(feature = "utils")]
+    #[serde(rename = "accent_color")]
+    pub accent_colour: Option<Colour>,
+    #[cfg(not(feature = "utils"))]
+    #[serde(rename = "accent_color")]
+    pub accent_colour: Option<u32>,
 }
 
 /// User's public flags
@@ -504,33 +535,35 @@ pub struct UserPublicFlags {
 __impl_bitflags! {
     UserPublicFlags: u32 {
         /// User's flag as discord employee
-        DISCORD_EMPLOYEE = 0b0000_0000_0000_0000_0000_0000_0000_0001;
+        DISCORD_EMPLOYEE = 1 << 0;
         /// User's flag as partnered server owner
-        PARTNERED_SERVER_OWNER = 0b0000_0000_0000_0000_0000_0000_0000_0010;
+        PARTNERED_SERVER_OWNER = 1 << 1;
         /// User's flag as hypesquad events
-        HYPESQUAD_EVENTS = 0b0000_0000_0000_0000_0000_0000_0000_0100;
+        HYPESQUAD_EVENTS = 1 << 2;
         /// User's flag as bug hunter level 1
-        BUG_HUNTER_LEVEL_1 = 0b0000_0000_0000_0000_0000_0000_0000_1000;
+        BUG_HUNTER_LEVEL_1 = 1 << 3;
         /// User's flag as house bravery
-        HOUSE_BRAVERY = 0b0000_0000_0000_0000_0000_0000_0100_0000;
+        HOUSE_BRAVERY = 1 << 6;
         /// User's flag as house brilliance
-        HOUSE_BRILLIANCE = 0b0000_0000_0000_0000_0000_0000_1000_0000;
+        HOUSE_BRILLIANCE = 1 << 7;
         /// User's flag as house balance
-        HOUSE_BALANCE = 0b0000_0000_0000_0000_0000_0001_0000_0000;
+        HOUSE_BALANCE = 1 << 8;
         /// User's flag as early supporter
-        EARLY_SUPPORTER = 0b0000_0000_0000_0000_0000_0010_0000_0000;
+        EARLY_SUPPORTER = 1 << 9;
         /// User's flag as team user
-        TEAM_USER = 0b0000_0000_0000_0000_0000_0100_0000_0000;
+        TEAM_USER = 1 << 10;
         /// User's flag as system
-        SYSTEM = 0b0000_0000_0000_0000_0001_0000_0000_0000;
+        SYSTEM = 1 << 12;
         /// User's flag as bug hunter level 2
-        BUG_HUNTER_LEVEL_2 = 0b0000_0000_0000_0000_0100_0000_0000_0000;
+        BUG_HUNTER_LEVEL_2 = 1 << 14;
         /// User's flag as verified bot
-        VERIFIED_BOT = 0b0000_0000_0000_0001_0000_0000_0000_0000;
+        VERIFIED_BOT = 1 << 16;
         /// User's flag as early verified bot developer
-        EARLY_VERIFIED_BOT_DEVELOPER = 0b0000_0000_0000_0010_0000_0000_0000_0000;
+        EARLY_VERIFIED_BOT_DEVELOPER = 1 << 17;
         /// User's flag as discord certified moderator
-        DISCORD_CERTIFIED_MODERATOR = 0b0000_0000_0000_0100_0000_0000_0000_0000;
+        DISCORD_CERTIFIED_MODERATOR = 1 << 18;
+        /// Bot's running with HTTP interactions
+        BOT_HTTP_INTERACTIONS = 1 << 19;
     }
 }
 
@@ -568,6 +601,8 @@ impl Default for User {
             discriminator: 1432,
             name: "test".to_string(),
             public_flags: None,
+            banner: None,
+            accent_colour: None,
         }
     }
 }
@@ -601,6 +636,17 @@ impl User {
         avatar_url(self.id, self.avatar.as_ref())
     }
 
+    /// Returns the formatted URL of the user's banner, if one exists.
+    ///
+    /// This will produce a WEBP image URL, or GIF if the user has a GIF banner.
+    ///
+    /// **Note**: This will only be present if the user is fetched via Rest API,
+    /// e.g. with [`Http::get_user`].
+    #[inline]
+    pub fn banner_url(&self) -> Option<String> {
+        banner_url(self.id, self.banner.as_ref())
+    }
+
     /// Creates a direct message channel between the [current user] and the
     /// user. This can also retrieve the channel if one already exists.
     ///
@@ -656,7 +702,13 @@ impl User {
     /// #   #[cfg(feature = "cache")]
     ///     async fn message(&self, ctx: Context, msg: Message) {
     ///         if msg.content == "~help" {
-    ///             let url = match ctx.cache.current_user().await.invite_url(&ctx, Permissions::empty()).await {
+    ///             let url = match ctx
+    ///                 .cache
+    ///                 .current_user()
+    ///                 .await
+    ///                 .invite_url(&ctx, Permissions::empty())
+    ///                 .await
+    ///             {
     ///                 Ok(v) => v,
     ///                 Err(why) => {
     ///                     println!("Error creating invite url: {:?}", why);
@@ -665,15 +717,9 @@ impl User {
     ///                 },
     ///             };
     ///
-    ///             let help = format!(
-    ///                 "Helpful info here. Invite me with this link: <{}>",
-    ///                 url,
-    ///             );
+    ///             let help = format!("Helpful info here. Invite me with this link: <{}>", url,);
     ///
-    ///             let dm = msg.author.direct_message(&ctx, |m| {
-    ///                 m.content(&help)
-    ///             })
-    ///             .await;
+    ///             let dm = msg.author.direct_message(&ctx, |m| m.content(&help)).await;
     ///
     ///             match dm {
     ///                 Ok(_) => {
@@ -690,7 +736,7 @@ impl User {
     /// }
     ///
     /// # async fn run() -> Result<(), Box<dyn std::error::Error>> {
-    /// let mut client =Client::builder("token").event_handler(Handler).await?;
+    /// let mut client = Client::builder("token").event_handler(Handler).await?;
     /// #     Ok(())
     /// # }
     /// # }
@@ -852,8 +898,8 @@ impl User {
     /// # use serenity::prelude::*;
     /// # use serenity::model::prelude::*;
     /// #
-    /// use serenity::utils::MessageBuilder;
     /// use serenity::utils::ContentModifier::Bold;
+    /// use serenity::utils::MessageBuilder;
     ///
     /// struct Handler;
     ///
@@ -870,7 +916,7 @@ impl User {
     ///         }
     ///     }
     /// }
-    /// let mut client =Client::builder("token").event_handler(Handler).await?;
+    /// let mut client = Client::builder("token").event_handler(Handler).await?;
     ///
     /// client.start().await?;
     /// #     Ok(())
@@ -908,7 +954,6 @@ impl User {
 
     /// Returns a future that will await one message by this user.
     #[cfg(feature = "collector")]
-    #[cfg_attr(docsrs, doc(cfg(feature = "collector")))]
     pub fn await_reply<'a>(
         &self,
         shard_messenger: &'a impl AsRef<ShardMessenger>,
@@ -918,7 +963,6 @@ impl User {
 
     /// Returns a stream builder which can be awaited to obtain a stream of messages sent by this user.
     #[cfg(feature = "collector")]
-    #[cfg_attr(docsrs, doc(cfg(feature = "collector")))]
     pub fn await_replies<'a>(
         &self,
         shard_messenger: &'a impl AsRef<ShardMessenger>,
@@ -928,7 +972,6 @@ impl User {
 
     /// Await a single reaction by this user.
     #[cfg(feature = "collector")]
-    #[cfg_attr(docsrs, doc(cfg(feature = "collector")))]
     pub fn await_reaction<'a>(
         &self,
         shard_messenger: &'a impl AsRef<ShardMessenger>,
@@ -938,7 +981,6 @@ impl User {
 
     /// Returns a stream builder which can be awaited to obtain a stream of reactions sent by this user.
     #[cfg(feature = "collector")]
-    #[cfg_attr(docsrs, doc(cfg(feature = "collector")))]
     pub fn await_reactions<'a>(
         &self,
         shard_messenger: &'a impl AsRef<ShardMessenger>,
@@ -1038,6 +1080,8 @@ impl From<CurrentUser> for User {
             id: user.id,
             name: user.name,
             public_flags: user.public_flags,
+            banner: user.banner,
+            accent_colour: user.accent_colour,
         }
     }
 }
@@ -1051,6 +1095,8 @@ impl<'a> From<&'a CurrentUser> for User {
             id: user.id,
             name: user.name.clone(),
             public_flags: user.public_flags,
+            banner: user.banner.clone(),
+            accent_colour: user.accent_colour,
         }
     }
 }
@@ -1116,6 +1162,15 @@ fn static_avatar_url(user_id: UserId, hash: Option<&String>) -> Option<String> {
     hash.map(|hash| cdn!("/avatars/{}/{}.webp?size=1024", user_id, hash))
 }
 
+#[cfg(feature = "model")]
+fn banner_url(user_id: UserId, hash: Option<&String>) -> Option<String> {
+    hash.map(|hash| {
+        let ext = if hash.starts_with("a_") { "gif" } else { "webp" };
+
+        cdn!("/banners/{}/{}.{}?size=1024", user_id.0, hash, ext)
+    })
+}
+
 #[cfg(feature = "model")]
 fn tag(name: &str, discriminator: u16) -> String {
     // 32: max length of username
