@@ -9,9 +9,10 @@ mod message_builder;
 
 #[cfg(all(feature = "client", feature = "cache"))]
 pub use argument_convert::*;
+use reqwest::Url;
 
 pub use self::{
-    colour::Colour,
+    colour::{colours, Colour},
     custom_message::CustomMessage,
     message_builder::{Content, ContentModifier, EmbedMessageBuilding, MessageBuilder},
 };
@@ -432,6 +433,35 @@ pub fn parse_quotes(s: impl AsRef<str>) -> Vec<String> {
     args
 }
 
+/// Parses the id and token from a webhook url. Expects a [`reqwest::Url`] object rather than a [`&str`].
+///
+/// # Examples
+///
+/// ```rust
+/// use serenity::utils;
+///
+/// let url_str = "https://discord.com/api/webhooks/245037420704169985/ig5AO-wdVWpCBtUUMxmgsWryqgsW3DChbKYOINftJ4DCrUbnkedoYZD0VOH1QLr-S3sV";
+/// let url = url_str.parse().unwrap();
+/// let (id, token) = utils::parse_webhook(&url).unwrap();
+///
+/// assert_eq!(id, 245037420704169985);
+/// assert_eq!(token, "ig5AO-wdVWpCBtUUMxmgsWryqgsW3DChbKYOINftJ4DCrUbnkedoYZD0VOH1QLr-S3sV");
+/// ```
+pub fn parse_webhook(url: &Url) -> Option<(u64, &str)> {
+    let path = url.path().strip_prefix("/api/webhooks/")?;
+    let split_idx = path.find('/')?;
+    let webhook_id = &path[..split_idx];
+    let token = &path[split_idx + 1..];
+    if !["http", "https"].contains(&url.scheme())
+        || !["discord.com", "discordapp.com"].contains(&url.domain()?)
+        || !(17..=20).contains(&webhook_id.len())
+        || !(60..=68).contains(&token.len())
+    {
+        return None;
+    }
+    Some((webhook_id.parse().ok()?, token))
+}
+
 /// Calculates the Id of the shard responsible for a guild, given its Id and
 /// total number of shards used.
 ///
@@ -802,6 +832,14 @@ mod test {
         assert_eq!(parsed, ["a", "b c", "d", "e f", "g"]);
     }
 
+    #[test]
+    fn test_webhook_parser() {
+        let url = "https://discord.com/api/webhooks/245037420704169985/ig5AO-wdVWpCBtUUMxmgsWryqgsW3DChbKYOINftJ4DCrUbnkedoYZD0VOH1QLr-S3sV".parse().unwrap();
+        let (id, token) = parse_webhook(&url).unwrap();
+        assert_eq!(id, 245037420704169985);
+        assert_eq!(token, "ig5AO-wdVWpCBtUUMxmgsWryqgsW3DChbKYOINftJ4DCrUbnkedoYZD0VOH1QLr-S3sV");
+    }
+
     #[cfg(feature = "cache")]
     #[tokio::test]
     async fn test_content_safe() {
@@ -818,6 +856,8 @@ mod test {
             discriminator: 0000,
             name: "Crab".to_string(),
             public_flags: None,
+            banner: None,
+            accent_colour: None,
         };
 
         #[allow(deprecated)]
@@ -888,6 +928,7 @@ mod test {
             #[cfg(feature = "unstable_discord_api")]
             permissions: None,
             avatar: None,
+            communication_disabled_until: None,
         };
 
         let role = Role {
@@ -901,6 +942,8 @@ mod test {
             permissions: Permissions::all(),
             position: 0,
             tags: RoleTags::default(),
+            icon: None,
+            unicode_emoji: None,
         };
 
         let channel = GuildChannel {
